<?php
/** Central Dusun (Dusun Bundu-liwan)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author FRANCIS5091
 * @author FRANELYA
 */

$fallback = 'ms';

$messages = array(
# User preference toggles
'tog-underline'               => 'Mangagaris pioputan:',
'tog-highlightbroken'         => 'Oturo noputan norumbak <a href="" class="new">miagal diti</a> (toi: miagal diti <a href="" class="internal">?</a>)',
'tog-justify'                 => 'Kasagaan kiparagrap',
'tog-hideminor'               => 'Lisoko idit tokoro ih wagu kaalanai.',
'tog-hidepatrolled'           => 'Lisoko idit tinamangan ih wagu kaalanai',
'tog-newpageshidepatrolled'   => 'Lisoko bolikon tinamangan mantad lis bolikon kawawagu',
'tog-extendwatchlist'         => 'Pointongo koinsanai listamangan do popokito koinsanai pinongundolihon, okon ko iri kawawagu nopo',
'tog-usenewrc'                => 'Tinimungan nopingalanan maya bobolikon ii wagu kaalanai om lispintangan (momoguno JawaSikrip)',
'tog-numberheadings'          => 'oporian-mongonumbur it tuluhon',
'tog-showtoolbar'             => 'Pokitono kakamotbar mongidit (momoguno JawaSikrip)',
'tog-editondblclick'          => 'Idito bolikon momoguno induaan todos (momoguno JawaSikrip)',
'tog-editsection'             => 'Pabanaro sikson mongidit mamakai noputan (idit)',
'tog-editsectiononrightclick' => 'Pabanaro sikson mongidit momoguno todos golibang id sikson tuluon (momoguno JawaSikrip)',
'tog-showtoc'                 => 'Pokitono mija sinuang-suang (montok bolikon di kolobi do 3 tuluhon)',
'tog-rememberpassword'        => 'Soroho ot loginku id popogihuman diti (gisom solinaid do $1 {{PLURAL:$1|tadau|madau}})',
'tog-watchcreations'          => 'Ruhangai bolikon di winonsoiku om nogi pail pinosuangku id lisintanganku',
'tog-watchdefault'            => 'Ruhangai bolikon om tangapail di niditku id lisintanganku',
'tog-watchmoves'              => 'Ruhangai bolikon om tangapail di pinawalihku id lisintanganku.',
'tog-watchdeletion'           => 'Ruhangai bolikon om tangapail di pinugasku id lisintanganku',
'tog-minordefault'            => 'Tandaai oinsanan niditan tokoro sobaagi do pongoiso',
'tog-previewontop'            => 'Pokitono duluon-kokikitanai id pogulu kutak idit',
'tog-previewonfirst'          => 'Pokitono duluon-kokikitanai di idit koinsan',
'tog-nocache'                 => 'Antabai kasing popogigihum bolikon',
'tog-enotifwatchlistpages'    => 'Ponuratai-i oku soira do haro bolikon toi pail lisintanganku haro nokowolion',
'tog-enotifusertalkpages'     => 'Ponuratai-i oku soira kiharo kowolion id pibabarasan momomogunoku',
'tog-enotifminoredits'        => 'Ponuratai-i oku nogi do nung haro no idit tongokoro do bolikon om nogi tangapail',
'tog-enotifrevealaddr'        => 'Pokitono adiris surat-i-ku id kapahabaran surat-i',
'tog-shownumberswatching'     => 'Pokitono ginumu do momomoguno minongintong',
'tog-oldsig'                  => 'Sain poinsandad:',
'tog-fancysig'                => 'Pokitono sain sobaagi do tikwiki (ingaa oporian toput )',
'tog-externaleditor'          => 'Pomoguno pongigidit poinlabus sobaagi do pongoiso (montok di angasampin nopo, mongoguno do nuludan pointantu id kompiutonu. [//www.mediawiki.org/wiki/Manual:External_editors Lobi pomoilaan.])',
'tog-externaldiff'            => 'Pomoguno pongigidit poinlabus sobaagi do pongoiso (montok di angasampin nopo, mongoguno do nuludan pointantu id kompiutonu. [//www.mediawiki.org/wiki/Manual:External_editors Lobi pomoilaan.])',
'tog-showjumplinks'           => 'Pasagao "tumopik hilo" noputan awayaan',
'tog-uselivepreview'          => 'Momoguno pongingintong poimpasi (momoguno JawaSikrip) (pogumbalan)',
'tog-forceeditsummary'        => 'Posoroho oku no nung awu nosuangan kutak koinibaan niditan',
'tog-watchlisthideown'        => 'Polisoko niditanku mantad do lis piintangan',
'tog-watchlisthidebots'       => 'Polisoko niditan rinobot mantad do lis pintangan',
'tog-watchlisthideminor'      => 'Polisoko niditan tokoto mantad do lis piintangan',
'tog-watchlisthideliu'        => 'Polisoko niditan di momomoguno sinumuang log mantad lis piintanganku',
'tog-watchlisthideanons'      => 'Polisoko niditan di momomoguno ingaa ngaran mantad id lis pintanganku',
'tog-watchlisthidepatrolled'  => "Polisoko niditan '''patrolled''' mantad do lis piintangan",
'tog-ccmeonemails'            => 'Atadai oku do dolinan di surat-i it pinaatodku montok momomoguno suai',
'tog-diffonly'                => 'Kada pokitono suang bobolikon id siriba tongodip',
'tog-showhiddencats'          => 'Pokitono katogori poinlisok',
'tog-norollbackdiff'          => 'Yadaai dip opongoh po do poturug-guli',

'underline-always'  => 'Toririmo',
'underline-never'   => 'Kada',
'underline-default' => 'Kourasai pogigihum sandad',

# Font style option in Special:Preferences
'editfont-style'     => 'Poyanan mongidit gaya pimato:',
'editfont-default'   => 'Pogigihum pongoiso',
'editfont-monospace' => 'Pimato iso insir',
'editfont-sansserif' => 'Pimato San-sorip',
'editfont-serif'     => 'Pimato Sorip',

# Dates
'sunday'        => 'Dautiwang',
'monday'        => 'Dautonlu',
'tuesday'       => 'Daumirod',
'wednesday'     => 'Daumansa',
'thursday'      => 'Dautadru',
'friday'        => 'Daurudu',
'saturday'      => 'Daukukuak',
'sun'           => 'DTiw',
'mon'           => 'DTon',
'tue'           => 'DMir',
'wed'           => 'DMad',
'thu'           => 'DTad',
'fri'           => 'DRud',
'sat'           => 'DKua',
'january'       => 'Tumilatok',
'february'      => 'Tumansak',
'march'         => 'Tugomot',
'april'         => 'Tungiop',
'may_long'      => 'Tumikat',
'june'          => 'Tumahas',
'july'          => 'Tumadas',
'august'        => 'Tumagus',
'september'     => 'Tumanom',
'october'       => 'Tugumas',
'november'      => 'Tumilau',
'december'      => 'Tumomuhau',
'january-gen'   => 'Milatok',
'february-gen'  => 'Mansak',
'march-gen'     => 'Gomot',
'april-gen'     => 'Ngiop',
'may-gen'       => 'Mikat',
'june-gen'      => 'Mahas',
'july-gen'      => 'Madas',
'august-gen'    => 'Magus',
'september-gen' => 'Manom',
'october-gen'   => 'Gumas',
'november-gen'  => 'Milau',
'december-gen'  => 'Momuhau',
'jan'           => 'Tok',
'feb'           => 'Sak',
'mar'           => 'Mot',
'apr'           => 'Iop',
'may'           => 'Kat',
'jun'           => 'Has',
'jul'           => 'Das',
'aug'           => 'Gus',
'sep'           => 'Nom',
'oct'           => 'Mas',
'nov'           => 'Lau',
'dec'           => 'Hau',

# Categories related messages
'pagecategories'                 => '{{PLURAL:$1|Katogori|Katogori}}',
'category_header'                => 'Bobolikon id kalas "$1"',
'subcategories'                  => 'Kawo do kalas',
'category-media-header'          => 'Modia id kalas "$1"',
'category-empty'                 => "''Maso po do ingga poinsuang bobolikon toi modia id kalas diti.''",
'hidden-categories'              => '{{PLURAL:$1|Kalas poinlisok|Ka-kalas poinlisok}}',
'hidden-category-category'       => 'Ka-kalas poinlisok',
'category-subcat-count'          => '{{PLURAL:$2|Ilo no kawo ka-kalas diti maso do babaino.|Ka-kalas diti kiharo {{PLURAL:$1|kawo kalas|$1 tangakawo kalas}}, soginumu do $2.}}',
'category-subcat-count-limited'  => 'Kalas diti kisuang do {{PLURAL:$1|kawo kalas|$1 ka-kawo kalas}}.',
'category-article-count'         => '{{PLURAL:$2|Kisuang do bolikon dilo nopo ot ka-kalas diti.|Soginumu {{PLURAL:$1|bolikon nopo|$1 bolikon di}} id kalas diti, mantad $2 koinsanai.}}',
'category-article-count-limited' => 'Iti {{PLURAL:$1|bolikon|$1 bobolikon}} hiti id katogori.',
'category-file-count'            => '{{PLURAL:$2|Kisuang ot ka-kalas diti do papail dilo.|Soginumu {{PLURAL:$1|pail nopo|$1 papail do}} id kalas diti, mantad $2 koinsanai.}}',
'category-file-count-limited'    => 'Iti {{PLURAL:$1|pail|$1 papail}} hiti id katogori.',
'listingcontinuesabbrev'         => 'Mononoluod',
'index-category'                 => 'Bolikon naka-abisi',
'noindex-category'               => 'Bolikon awu naka-abisi',
'broken-file-category'           => 'Bobolikon miampai pongoput pail do noputut',

'about'         => 'Kokomoi',
'article'       => 'Suang bolikon',
'newwindow'     => '(ukabai id liligaon wagu)',
'cancel'        => 'Kinsilo',
'moredotdotdot' => 'Gumu...',
'mypage'        => 'Bolikon',
'mytalk'        => 'Pogibabarasan',
'anontalk'      => 'Piboros montok diti nantadon IP',
'navigation'    => 'Popotunud',
'and'           => '&#32;om',

# Cologne Blue skin
'qbfind'         => 'Ihum',
'qbbrowse'       => 'Pogihum',
'qbedit'         => 'Idito',
'qbpageoptions'  => 'Bolikon diti',
'qbpageinfo'     => 'Pogiromutan',
'qbmyoptions'    => 'Bobolikonku ngawi',
'qbspecialpages' => 'Bobolikon suaikowokon',
'faq'            => 'Ponguhatan Koinsoruan om Poninimbar',
'faqpage'        => 'Project:Ponguhatan Koinsoruan om Pininimbar',

# Vector skin
'vector-action-addsection'       => 'Ruhangai piboboroson',
'vector-action-delete'           => 'Pugaso',
'vector-action-move'             => 'Poundoliho',
'vector-action-protect'          => 'Tingoligai',
'vector-action-undelete'         => 'Kada pugaso',
'vector-action-unprotect'        => 'Alanai tingolig',
'vector-simplesearch-preference' => 'Pasagao pogigihum bar noinsanangan (Pongulit tuntuduk nopo)',
'vector-view-create'             => 'Pomonsoi',
'vector-view-edit'               => 'Idito',
'vector-view-history'            => 'Intaai susuyan',
'vector-view-view'               => 'Basao',
'vector-view-viewsource'         => 'Intaai wowonod',
'actions'                        => 'Pongkinaraja',
'namespaces'                     => 'Ponuratan ngaran',
'variants'                       => 'Kopogisuaian',

'errorpagetitle'    => 'Nosilopan',
'returnto'          => 'Gumuli hilo $1.',
'tagline'           => 'Mantad {{SITENAME}}',
'help'              => 'Sokodung',
'search'            => 'Ihumo',
'searchbutton'      => 'Ihumo',
'go'                => 'Ongoi',
'searcharticle'     => 'Ongoyo',
'history'           => 'Susuyan bolikon',
'history_short'     => 'Susuyan',
'updatedmarker'     => 'noinwoguan mantad di poguluku do tuminombului',
'printableversion'  => 'Solinan milo pirinon',
'permalink'         => 'Toput pointatap',
'print'             => 'Pirino',
'view'              => 'Intaai',
'edit'              => 'Idito',
'create'            => 'Pomonsoi',
'editthispage'      => 'Idito iti bolikon',
'create-this-page'  => 'Pudoliai iti bolikon',
'delete'            => 'Pugaso',
'deletethispage'    => 'Pugaso iti bolikon',
'undelete_short'    => 'Kada pugaso {{PLURAL:$1|iso niditan|$1 niniditan}}',
'viewdeleted_short' => 'Intaai {{PLURAL:$1|iso niditan pinugas|$1 niniditan pinugas}}',
'protect'           => 'Tingoligai',
'protect_change'    => 'alanai',
'protectthispage'   => 'Tingoligai iti bolikon',
'unprotect'         => 'Alanai tingolig',
'unprotectthispage' => 'Alanai tingoligai iti bolikon',
'newpage'           => 'Bolikon wagu',
'talkpage'          => 'Pitimbungakai iti bolikon',
'talkpagelinktext'  => 'Boroson',
'specialpage'       => 'Bolikon suaikowokon',
'personaltools'     => 'Kakamot minsosondiri',
'postcomment'       => 'Bogian wagu',
'articlepage'       => 'Intaai suang bolikon',
'talk'              => 'Pogigibarasan',
'views'             => 'Pongintangan',
'toolbox'           => 'Kabankamot',
'userpage'          => 'Intaai bolikon momomoguno',
'projectpage'       => 'Intaai bolikon purujik',
'imagepage'         => 'Intaai bolikon pail',
'mediawikipage'     => 'Intaai bolikon pason',
'templatepage'      => 'Intaai tompilat bolikon',
'viewhelppage'      => 'Intaai bolikan sokodung',
'categorypage'      => 'Intaai bolikon koinansar',
'viewtalkpage'      => 'Intaai pitimbungakan',
'otherlanguages'    => 'Id woyoboros suai',
'redirectedfrom'    => '(Pinotilombus mantad $1)',
'redirectpagesub'   => 'Bolikon pinotilombus',
'lastmodifiedat'    => 'Bolikon diti komodipait di ontok $1, jaam $2.',
'viewcount'         => 'Nawayaan bolikan diti do {{PLURAL:$1|insan|in-$1}}.',
'protectedpage'     => 'Bolikon tiningoligan',
'jumpto'            => 'Tilombus hilo:',
'jumptonavigation'  => 'popotunud',
'jumptosearch'      => 'ihumo',
'view-pool-error'   => 'Siou tu nakalabai tomod ilo kompiuto mamamalayan.
Adalaan togumu momomoguno do mingumbal mongintong diti bolikon.
Andadon po do toruhai pogulu do mangapil sumuang id bolikon diti.

$1',
'pool-timeout'      => 'Nakatalib timpu magandad do mongunsi',
'pool-queuefull'    => 'Noponu nuludan pool',
'pool-errorunknown' => 'Ukam nosilap',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Kokomoi {{SITENAME}}',
'aboutpage'            => 'Project:Kokomoi',
'copyright'            => 'Suang di haro do kokomoi $1.',
'copyrightpage'        => '{{ns:project}}:Sanganuwonsoi',
'currentevents'        => 'Poimpanau po',
'currentevents-url'    => 'Project:Poimpanau poh',
'disclaimers'          => 'Pogoliman',
'disclaimerpage'       => 'Project:Pogoliman kosoruan',
'edithelp'             => 'Sokodung mongidit',
'edithelppage'         => 'Help:Mongidit',
'helppage'             => 'Help:Susuang',
'mainpage'             => 'Natad tagayo',
'mainpage-description' => 'Natad tagayo',
'policy-url'           => 'Project:Kooturan',
'portal'               => 'Potal mamasok',
'portal-url'           => 'Project:Potal doun mamasok',
'privacy'              => 'Kopitimbangan ahaltinan',
'privacypage'          => 'Project:Kopitimbangan ahaltinan',

'badaccess'        => 'Nokosilap papasaga',
'badaccess-group0' => 'Pogoduhan ko do papapanau di pingkarajaon it pinokianu nu.',
'badaccess-groups' => 'Pingkarajaon di pinokianu nu pinatantu montok momomoguno do {{PLURAL:$2|kotinimungan|iso mantad kotinimungan}}: $1.',

'versionrequired'     => 'Momoguno do borsi $1 ModiaWiki',
'versionrequiredtext' => 'Dinolinan $1 do ModiaWiki pokionuon do mongoguno diti bolikon.
Intaai [[Special:Version|bolikon dinolinan]].',

'ok'                      => 'Oboh',
'retrievedfrom'           => 'Naanu mantad "$1"',
'youhavenewmessages'      => 'Kiharo $1 montok dia ($2).',
'newmessageslink'         => 'pason kawawagu',
'newmessagesdifflink'     => 'naalanan kawawagu',
'youhavenewmessagesmulti' => 'Kipason kawawagu montok dia id $1',
'editsection'             => 'idito',
'editold'                 => 'idito',
'viewsourceold'           => 'intaai wowonod',
'editlink'                => 'idito',
'viewsourcelink'          => 'intaai wowonod',
'editsectionhint'         => 'Sikson mongidit: $1',
'toc'                     => 'Suang-suang',
'showtoc'                 => 'popointalang',
'hidetoc'                 => 'popolisok',
'collapsible-collapse'    => 'Doropio',
'collapsible-expand'      => 'Pawalado',
'thisisdeleted'           => 'Intaai toi poguli gompi $1?',
'viewdeleted'             => 'Intaai $1?',
'restorelink'             => '{{PLURAL:$1|iso niditan pinugas|$1 niniditan nopinpugasan}}',
'feedlinks'               => 'Papababu:',
'feed-invalid'            => 'Nokosilap kakamot magaganu papababu.',
'feed-unavailable'        => 'Ingaa sontinimungan papapababu',
'site-rss-feed'           => '"$1"  papababu RSS',
'site-atom-feed'          => '"$1" Papababu Atom',
'page-rss-feed'           => '"$1"  papababu RSS',
'page-atom-feed'          => '"$1" Papababu Atom',
'red-link-title'          => '$1 (bolikon awu poinsuang)',
'sort-descending'         => 'Uludo poinruhuk',
'sort-ascending'          => 'Uludo pointakad',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Bolikon',
'nstab-user'      => 'Bolikon momomoguno',
'nstab-media'     => 'Bolikon modia',
'nstab-special'   => 'Bolikon suaikowokon',
'nstab-project'   => 'Bolikon purujik',
'nstab-image'     => 'Pail',
'nstab-mediawiki' => 'Pason',
'nstab-template'  => 'Pomitanan',
'nstab-help'      => 'Bolikon monulung',
'nstab-category'  => 'Katogori',

# Main script and global functions
'nosuchaction'      => 'Ingaa nowonsoi nokomoi',
'nosuchactiontext'  => 'Nokosilap winonsoi pointontu dilo URL.
Nosilapannu manaip ilo URL, toi nakawaya ko di toput nakaansau.
Kaanto do haro kutu id ponuang-suangon gunoon id {{SITENAME}}.',
'nosuchspecialpage' => 'Ingaa bolikon pinotontu',
'nospecialpagetext' => '<strong>Nokopokianu ko diri bolikon pinatantu poinsilap.</strong>

Lis pointopot bobolikon pinatantu okito id [[Special:SpecialPages|{{int:specialpages}}]].',

# General errors
'error'                => 'Nosilopan',
'databaseerror'        => 'Nakasala databing',
'dberrortext'          => 'Nokosilap pogiuludan databing.
Haro kaanto kutu id posuang-suangon.
Tohuri pinokianu pogiuludan databing nopo nga:
<blockquote><code>$1</code></blockquote>
mantad suang momoguno "<code>$2</code>".
Databing nokosilap pinopoguli "<samp>$3: $4</samp>".',
'dberrortextcl'        => 'Haro kinosilapan pinongimuhatan sintak diri databing.
Pinokianu databing di nokotohuri nopo nga:
"$1"
mantad kopomogunoon "$2".
Nokosilap pinonimbar databing do "$3: $4"',
'laggedslavemode'      => "'''Panansarahan:''' Awu moti kaanto nopinwoguan suang do bolikon diti.",
'readonly'             => 'Nokunsian databing',
'enterlockreason'      => 'Posuango sabab do mongunsi, poobion do gisom soira oukaban kunsi',
'readonlytext'         => 'Databing diti nokunsian mantad monuang-suang om nogi pinsimbanan, koubasan do maso doropion, nga koguli miagal kasari do opongoh po ilo.

Mandur di minongunsi minomisunud do: $1',
'missing-article'      => 'Paildata diti awu nokokito do tik id bolikon diti ih mositi do gunoon, iri pinungaranan do "$1" $2.

Koubasan do ajadi miagal diti tu haro nopingalanan toi ko toput mongoi id bolikon laid nopugas nodi.

Nung opurimanannu do okon ko iti o sabab, korubo ko do bug id posusuangon diti.
Mangai poruputo iti hilod [[Special:ListUsers/sysop|mantatamong]], miampai nota kokomoi do \'URL\'.',
'missingarticle-rev'   => '(sinimakan#: $1)',
'missingarticle-diff'  => '(Dip: $1, $2)',
'readonly_lag'         => 'Databing noporianan nokokunsi daamot do databing mamalayan kumoduo mongogusa dilo kumoiso',
'internalerror'        => 'Kinosilapan poinsuang',
'internalerror_info'   => 'Kinosilapan poinsuang: $1',
'fileappenderrorread'  => 'Awu abasa "$1" maso pinapaapil.',
'fileappenderror'      => 'Awu kapaapil "$1" mongoi "$2".',
'filecopyerror'        => 'Awu kadalin pail  "$1" gisom "$2".',
'filerenameerror'      => 'Awu  nopingaranan pail "$1" mongoi "$2".',
'filedeleteerror'      => 'Awu nopugas pail "$1".',
'directorycreateerror' => 'Awu kowonsoi pailtuduk "$1".',
'filenotfound'         => 'Awu oihum pail "$1"',
'fileexistserror'      => 'Awu kasaga do monurat pail "$1": kipail noh',
'unexpected'           => 'Awu nopoimanan gatang: "$1"="$2".',
'formerror'            => 'Silap: awu kapaatod pom',
'badarticleerror'      => 'Awu milo momonsoi dino id bolikon diti.',
'cannotdelete'         => 'Iti bolikon toi pail "$1" awu milo pugason.
Nopugas no kaanto do tulun suai.',
'cannotdelete-title'   => 'Awu milo pugason bolikon "$1"',
'badtitle'             => 'Sosomu tuluhon',
'badtitletext'         => 'Tuluhon bobolikon di pinokianu nopo nga nokosilap, aiso, nakasala pinioputan boros toi pinioputan tuluhon wiki.
Haro kaanto sokukuri do iso pimato it awu milo gunoon id pongkotuluhon.',
'perfcached'           => 'Data sumusuhut namadangkob om okon ko noinwoguan. Sokiginumu do  {{PLURAL:$1|iso asil|$1 tangahasil nopo nga}} haro id dangkob diti.',
'perfcachedts'         => 'Data sumusuhut namadangkob, om nopinwoguan ontok $1. Sokiginumu {{PLURAL:$4|iso asil|$4 tangahasil nopo nga}} haro id dangkob diti.',
'querypage-no-updates' => 'Pinisok ponginwoguan id bolikon diti.
Awu nodi posikapon do popointalang iri data kawawagu.',
'wrong_wfQuery_params' => 'Nokosilap tangaparamito mongoi wfQuery()<br />
Kopomogunoon: $1<br />
Pongimuhatan: $2',
'viewsource'           => 'Intaai wowonod',
'viewsource-title'     => 'Intaai wowonod montok do $1',
'actionthrottled'      => 'Momilos',
'actionthrottledtext'  => 'Pinapanau lumawan-singkarap, Nantaban ko do mingguli momonsoi miagal dilo id timpu do osikap, om nagampot nu noh gisom diti.
Umbalan kawagu do katalib poh pipiro minit.',
'protectedpagetext'    => 'Bolikon diti notingoligan tu mangantob do pinsimbanan toi pingkukuroyon nopo.',
'viewsourcetext'       => 'Pasagaon ko do mongintong om mangadalin wowonod diti bolikon:',
'viewyourtext'         => "Milo nu do intangan om solinon ot wowonod '''niditannu''' id bolikon diti:",
'protectedinterface'   => 'Bolikon diti kiharo sinuratan pongurasan montok posusuang-suangon, om notingoligan do momiara mantad pomirumbakan.
Nung mongoruhang toi monimban do waliwboros tongowiki, mangai noh gunoo iri purujik popodusun do Modiawiki id [//translatewiki.net/ translatewiki.net].',
'editinginterface'     => "Panansarahan :''' Mongidit ko diti bolikon di gunoon do poposodia diri pongurasan montok posuang-suangon.
Sinuratan id bolikon diti kopogoit do pongitanan  kourasan momoguno  montok momomoguno suai.
Montok mongoruhang toi monimban do waliwboros, gunoo noh [//translatewiki.net/ translatewiki.net], purujik popodusun ModiaWiki.",
'sqlhidden'            => '(Pongimuhatan SQL poinlisok)',
'cascadeprotected'     => 'Notingoligan bolikon diti mantad do pingiditan tu nokosuang  id bolikon, {{PLURAL:$1 | do | it}} pinilian tingolig  "kasading" poinsikit:
$2',
'namespaceprotected'   => "Ingaa kasagaannu do mongidit bobolikon it kinoingaran '''$1'''.",
'customcssprotected'   => 'Ingaa kasagaannu do mongidit diti bolikon CSS, tu kisuang ponguludan minsosondiri momoguno.',
'customjsprotected'    => 'Ingaa kasagaannu do mongidit diti bolikon JavaScript, tu kisuang ponguludan minsosondiri momoguno.',
'ns-specialprotected'  => 'Bolikon pinotontu awu milo iditon.',
'titleprotected'       => 'Notingoligan tuluhon diti mantad wonsoyon do [[User:$1|$1]].
Sasabab no do "\'\'$2\'\'".',

# Virus scanner
'virus-badscanner'     => "Araat kinooturon: Awu otutunan pongkowili giuk: ''$1''",
'virus-scanfailed'     => 'nolibai pongkowili (code $1)',
'virus-unknownscanner' => 'tantobgiuk awu otutunan:',

# Login and logout pages
'logouttext'                 => "'''Baino nakalabus log ko noh.'''

Milo ko do monilombus mongoguno {{SITENAME}} poinlisok, toi [[Special:UserLogin|sumuang log koh kawagu]] miagal ngaran di tiinu toi mongoguno ngaran suai.
Birio do kipipiro bolikon popokito do maso poinsuang log koh poh gisom no do opugas nu dangkob do pogigihumnu.",
'welcomecreation'            => '== Kopiwosian, $1! ==
Nowonsoi no takaunnu.
Soroho no do mongolon [[Special:Preferences|{{SITENAME}} komoisoonnu]].',
'yourname'                   => 'Ngarandait:',
'yourpassword'               => 'Kaatalib:',
'yourpasswordagain'          => 'Mintaipo kaatalib:',
'remembermypassword'         => 'Soroho ot loginku id popogihuman diti (gisom solinaid do $1 {{PLURAL:$1|tadau|madau}})',
'securelogin-stick-https'    => 'Toririmo poinhubung hilo HTTPS soira kosuang log',
'yourdomainname'             => 'Damin nu:',
'externaldberror'            => 'Haro nokosilap pongintutunan bingdata toi awu ko pasagaon monginwagu takaun poinsoliwannu.',
'login'                      => 'Sumuang log',
'nav-login-createaccount'    => 'Sumuang log / pomonsoi  do takaun',
'loginprompt'                => 'Suhuonko do poposikit pongongonsok do sumuang log id {{SITENAME}}.',
'userlogin'                  => 'Sumuang log / pomonsoi  do takaun',
'userloginnocreate'          => 'Sumuang log',
'logout'                     => 'Lumabus log',
'userlogout'                 => 'Lumabus log',
'notloggedin'                => 'Amu nokolog sumuang',
'nologin'                    => 'Ingaa akaun? $1',
'nologinlink'                => 'Pomonsoi do akaun',
'createaccount'              => 'Pomonsoi do takaun',
'gotaccount'                 => 'Kitakaun? $1',
'gotaccountlink'             => 'Sumuang log',
'userlogin-resetlink'        => 'Nolihuan ahal loginnu?',
'createaccountmail'          => 'Maya surat-i',
'createaccountreason'        => 'Sabab:',
'badretype'                  => 'Kaatalib pinosuang awu kopisangai.',
'userexists'                 => 'Ngaranmoguno pinosuang noguno no.
Maai alanai do suai ngaran.',
'loginerror'                 => 'Nokosilap sumuang log',
'createaccounterror'         => 'Awu kowonsoi takaun: $1',
'nocookiesnew'               => 'Nowonsoi no takaun momoguno, nga awu ko poinsuang log.
{{SITENAME}} mongoguno kukis do posuang log.
Pointingkod kukisnu.
Papanaho ilo, om sumuang log momoguno do ngaranmoguno om kaatalib wagunu.',
'nocookieslogin'             => '{{SITENAME}} mongoguno kukis do sumuang log.
Pointingkod kukis kompiutonu.
Mangai papanaho ilo om umbalan kawagu.',
'nocookiesfornew'            => 'Awu po nowonsoi takaun momoguno, tu awu otunudan wowonod dau.
Posikito no pogogonsoknu, gumulisuang id bolikon diti om umbalan kawagu.',
'noname'                     => 'Awu nu pinosuang ngaran momomoguno di pasagaon.',
'loginsuccesstitle'          => 'Nokosuang log.',
'loginsuccess'               => "'''Nokosuang log ko noh id {{SITENAME}} sobaagi do \"\$1\".'''",
'nosuchuser'                 => 'Ingaa momoguno pinungaranan "$1".
Ngaran momoguno nopo nga kowoyo pimato.
Intaai ijaannu, toi [[Special:UserLogin/signup|pomonsoi do takaun kawawagu]].',
'nosuchusershort'            => 'Ingaa momoguno kingaran  "$1".
Intaai ijaannu.',
'nouserspecified'            => 'Maai posuango ngaran momoguno.',
'login-userblocked'          => 'Nantaban momoguno diti. Oduhan do sumuang log.',
'wrongpassword'              => 'Nokosilap kaatalib pinosuang.
Umbalan kawagu kio.',
'wrongpasswordempty'         => 'Ingaa kapaas pinosuang.
Umbalai gia kaagu.',
'passwordtooshort'           => 'Sokukuri do kapaas kiharo {{PLURAL:$1|1 pimato|$1 tongopimato}}.',
'password-name-match'        => 'Kapaasnu mositi do pisuaion mantad ko ngaranmogunonu.',
'password-login-forbidden'   => 'Pogoduhan pomogunaan ngaran momoguno om kaatalib diti.',
'mailmypassword'             => 'Ponurat-i kaatalib wagu',
'passwordremindertitle'      => 'Kaatalib wagu daamot nopo montok {{SITENAME}}',
'passwordremindertext'       => 'Sosongulun (ika nogi matuu, mantad kinoyonon IP $1) minokianu
kaatalib montok {{SITENAME}} ($4). Kaatalib daamot montok momoguno
"$2" nowonsoi om noguno hilo "$3". Nung iti nopo komoyonnu, ongoi no suang log om pilio kaatalib wagu do baino. Kaatalib daamot diti nopo nga opupusan solinaid {{PLURAL:$5|sangadau|$5 madau}}.

Nung sosongulun iri minokianu do kaatalib diti, toi osorou nu nodi kaatalibnu, om awu nu alanan iri, milo ko do mogolim diti pason om monilombus mongoguno di kaatalib laidnu.',
'noemail'                    => 'Ingaa poinsurat paatadan surat-i montok momoguno "$1".',
'noemailcreate'              => 'Posuango porikatan surat-i di otopot',
'passwordsent'               => 'Nakaatod kaatalib wagu hilo id porikatan surat-i poinrijisto montok "$1".
Gumuli sumuang log do aramit nu noh iri kio.',
'blocked-mailpassword'       => 'Nantaban kinoyonon IP do karaja mongidit, om nantaban mongoguno kangkaraja manampasi kaatalib do magalai salaguno.',
'eauthentsent'               => 'Kopogiratan surat-i nakaatod noh hilo kinoiyonon surat-i nokomoi.
Pogulu do kaatod suai surat-i mongoi id takaun dilo, tonudo noh karalan-ralano poinsuang id surat-i, do mongogirot do dia kopio dilo takaun.',
'throttled-mailpassword'     => 'Nakaatod no iso panansarahan do kaatalib , solinaid {{PLURAL:$1|jam|$1 jaam}}.
Montok magalai do salaguno, iso no kaatalib maan pootodo monikid {{PLURAL:$1|jam|$1 jaam}}.',
'mailerror'                  => 'Nakasala paatod surat: $1',
'acct_creation_throttle_hit' => 'Tombului id wiki monomoguno do kinoyonon IPnu om nokopomonsoi {{PLURAL:$1|1 takaun|$1 tangakaun}} di kawawagu, it pasagaan poinggumu do maso diti.
Kootuson nopo di, tongotombului mongoguno kinoyonon IP diti awu poh kopomonsoi do takaun do daamot diti.',
'emailauthenticated'         => 'Nogiratan no surat-i nu ontok $2 jaam ko-$3.',
'emailnotauthenticated'      => 'Awu poh nogiratan ot kinoyonon surat-i nu.
Ingaa sinuratan-i pootodon montok nonggo-nonggo ilo komoyon sumusuhut.',
'noemailprefs'               => 'Patatapo no kinoyonon surat-i id komoisoonnu mooi do poposikit kowo-woyo diti',
'emailconfirmlink'           => 'Pogiroto no surat-i nu.',
'invalidemailaddress'        => 'Awu aramit kinoyonon surat-i tu nokosilap nuludan.
Maai posuango nuludan tosonong do kinoyonon toi pologoson do ingaa suang dilo posuangan.',
'cannotchangeemail'          => 'Porikatan surat-i do akaun diti awu milo do simbanan id wiki diti.',
'accountcreated'             => 'Nowonsoi takaun',
'accountcreatedtext'         => 'Momoguno takaun montok $1 nowonsoi noh.',
'createaccount-title'        => 'Winonsoi takaun montok {{SITENAME}}',
'createaccount-text'         => 'Sosongolun minomonsoi takaun montok kinoyonon surat-i nu id {{SITENAME}} ($4) pinungaranan "$2", miampai kaatalib "$3".
Baino alapon ko do sumuang log om mongolon diti kaatalibnu.

Olingan nopo iti pason, nung nokosilap nowonsoi iti takaun.',
'usernamehasherror'          => 'Ngaranmoguno awu milo do kipimato hansar',
'login-throttled'            => 'Asaru ko no do minsingumbal sumuang log.
Andado poh do toruhai pogulu do minsingumbal kawagu.',
'login-abort-generic'        => 'Awu ko nokosuang log - Binatal',
'loginlanguagelabel'         => 'Woyoboros: $1',
'suspicious-userlogout'      => 'Awu naramit lumabus lognu tu pinaatod mantad pogigihum norumbak toi caching olon.',

# Email sending
'php-mail-error-unknown' => 'Awu nointutunan kinosilapan id don surat PHP () function',
'user-mail-no-addy'      => 'Mogumbal do papaatod surat-i tingaa o paatadan.',

# Change password dialog
'resetpass'                 => 'Alanai kaatalib',
'resetpass_announce'        => 'Poinsuang log ko momoguno do kaatalib daamot it pinosurat-i.
Momongoh do sinuang log, mositi do powonsoionnu kaatalib wagu do hiti.:',
'resetpass_header'          => 'Alanai kaatalib takaun',
'oldpassword'               => 'Kaatalib laid:',
'newpassword'               => 'Kaatalib wagu:',
'retypenew'                 => 'Mitaipo kaatalib wagu:',
'resetpass_submit'          => 'Posoino kaatalib om sumuang log',
'resetpass_success'         => 'Naalanan noh kaatalibnu!
Baino sumuang log...',
'resetpass_forbidden'       => 'Awu milo alanan kaatalib',
'resetpass-no-info'         => 'Mositi sumuang log ko do mongoguno monilombus id bolikon diti.',
'resetpass-submit-loggedin' => 'Alanai kaatalib',
'resetpass-submit-cancel'   => 'Kinsilo',
'resetpass-wrong-oldpass'   => 'Nokosilap kaatalib daamot toi iy maso gunoon.
Naalanannu noh kaatalib toi nokopokianu koh no do kaatalib daamot.',
'resetpass-temp-password'   => 'Kaatalib daamot:',

# Special:PasswordReset
'passwordreset'                    => 'Pudoliai kawagu kaatalib',
'passwordreset-text'               => 'Gonopo poom diti do mangaramit tongosurat-i ponorou do nokomoi id akaun.',
'passwordreset-legend'             => 'Pudoliai kawagu kaatalib',
'passwordreset-disabled'           => 'Pomudolian kawagu do kaatalib kitaantob id wiki diti.',
'passwordreset-pretext'            => '{{PLURAL:$1||Posuango iso data id siriba}}',
'passwordreset-username'           => 'Ngarandait:',
'passwordreset-domain'             => 'Sumanganu:',
'passwordreset-capture'            => 'Intaai surat-i dii nowonsoi?',
'passwordreset-capture-help'       => 'Nung goritannu id kutak diti, surat-i (ii ki-kaa-talib daamot) mangan pokitanai montok dia om nogi porikoton montok momomoguno diti.',
'passwordreset-email'              => 'Porikatan surat-i:',
'passwordreset-emailtitle'         => 'Kointalangan takaun id {{SITENAME}}',
'passwordreset-emailelement'       => 'Ngaranmoguno: $1
Kaatalib daamot: $2',
'passwordreset-emailsent'          => 'Surat-i pononsorou nakaatod noh.',
'passwordreset-emailsent-capture'  => 'Surat-i pononsorou nakaatod noh, miagal id siriba diti.',
'passwordreset-emailerror-capture' => 'Surat-i pononsorou nopudali noh, miagal id siriba diti, nga awu kaatod id momomoguno: $1',

# Special:ChangeEmail
'changeemail'          => 'Alanai porikatan surat-i',
'changeemail-header'   => 'Alanai akaun porikatan surat-i',
'changeemail-text'     => 'Gonopo poom diti do mongolon porikatan surat-i nuh. Mangai posuango kaatalibnu do papasaah di naalanan.',
'changeemail-no-info'  => 'Mositi sumuang log ko do mongoguno monilombus id bolikon diti.',
'changeemail-oldemail' => 'Porikatan surat-i maso diti:',
'changeemail-newemail' => 'Porikatan surat-i it kawawagu:',
'changeemail-none'     => '(ingaa)',
'changeemail-submit'   => 'Alanai surat-i',
'changeemail-cancel'   => 'Kinsilo',

# Edit page toolbar
'bold_sample'     => 'Polombono tik',
'bold_tip'        => 'Polombono tik',
'italic_sample'   => 'Tik lingging',
'italic_tip'      => 'Tik lingging',
'link_sample'     => 'Noputan tuluhon',
'link_tip'        => 'Noputan poinsuang',
'extlink_sample'  => 'http://www.example.com tuluon do noput',
'extlink_tip'     => 'Noputan poinlabus (soroho no do potitimpuun http://)',
'headline_sample' => 'Tik potuluhon',
'headline_tip'    => 'Nuludan-tulu loting ko-2',
'nowiki_sample'   => 'Posuango tik awu-nokoulud do hiti',
'nowiki_tip'      => 'Pologoso ponguludan wiki',
'image_tip'       => 'Potopilo pail',
'media_tip'       => 'Toput do pail',
'sig_tip'         => 'Tinonduktunturunu miampai sinokot-timpu',
'hr_tip'          => 'Puralan pointibabar (inta-taan do mongoguno)',

# Edit pages
'summary'                          => 'Koinibaan:',
'subject'                          => 'Ahal/tuluhon',
'minoredit'                        => 'Iti nopo nga niditan tokoto',
'watchthis'                        => 'Piintong bolikon diti',
'savearticle'                      => 'Umoligai bolikon',
'preview'                          => 'Kokitanan',
'showpreview'                      => 'Pokitono pongintangan',
'showlivepreview'                  => 'Kokitanan monilombus',
'showdiff'                         => 'Pokitono nokowolion',
'anoneditwarning'                  => "'''Woning:''' Awu ko poinlog sumuang.
Nantadon IPnu maan podolino id susuyan bolikon nidit do hiti.",
'anonpreviewwarning'               => "''Awu ko poinsuang log. Popogompi do sinuratan koponurat do kinoyonon IPnu id bobolikon susuyan niditan.''",
'missingsummary'                   => "'''Panansarahan:''' Awu nu nosuratan hilo id koinibaan niditan.
Nung todosonnu \"{{int:savearticle}}\" kawagu, kogompi niditannu nga ingaa koinibaan.",
'missingcommenttext'               => 'Mangai gia posuango pason id siriba.',
'missingcommentheader'             => "'''Panansarahan:''' Awu nu nokosuang ahal/tuluhon montok pason diti.
Nung todosonnu \"{{int:savearticle}}\" kawagu, kogompi niditannu nga ingaa aha//tuluhon.",
'summary-preview'                  => 'Pongitanan koinibaan:',
'subject-preview'                  => 'Pongitanan ahal/tuluhon:',
'blockedtitle'                     => 'Nantaban momoguno',
'blockedtext'                      => "'''Ngaran momogunonu toi kinoyonon IP nantaban.'''

Nantaban di $1.
Sabab pinatahak ''$2''.

* Tinimpuun nantaban: $8
* Olimpupusan nantaban: $6
* Koinggisaman tantob: $7

Milo ko do tumurubung $1 toi [[{{MediaWiki:Grouppage-sysop}}|mandur]] suai do miboros kokomoi diti tantob.
Awu ko milo do mongoguno kakamot 'ponurat-i montok momoguno diti' nung ingaa kinoyonon surat-i pointantu id [[Special:Preferences|takaunnu]] om awu ko nantaban do momoguno dilo.
Kinoyonon IPnu nopo nga $3, on ID nantaban nopo nga #$5.
Alansan do potonudon oinsanan kointalangan id sawat montok nunu-nunu ponguhatannu.",
'autoblockedtext'                  => "Kinoyonon IPnu noporianan nantaban tu gunoon do momomoguno suai, it nantaban di $1.
Sabab pinatahak diti:

:''$2''


* Tinimpuun nantaban: $8
* Olimpupusan nantaban: $6
* Koinggisaman tantob: $7

Milo ko do tumurubung $1 toi [[{{MediaWiki:Grouppage-sysop}}|mandur]] suai do miboros kokomoi diti tantob.

Awu ko milo do mongoguno kakamot 'ponurat-i montok momoguno diti' nung ingaa kinoyonon surat-i pointantu id [[Special:Preferences|takaunnu]] om awu ko nantaban do momoguno dilo.

Kinoyonon IPnu nopo nga $3, on ID nantaban nopo nga #$5.
Alansan do potonudon oinsanan kointalangan id sawat montok nunu-nunu ponguhatannu.",
'blockednoreason'                  => 'ingaa pinatahak sabab',
'whitelistedittext'                => 'Mositi do $1 do mongidit bobolikon.',
'confirmedittext'                  => 'Potontuo no do nokogirotnu no kinoyonon surat-i pogulu mongidit do bobolikon.
Maai posoino om pogiroto kinoiyonon surat-i hilo id [[Special:Preferences|komoisaan momomogunonu]].',
'nosuchsectiontitle'               => 'Awu okito boogian',
'nosuchsectiontext'                => 'Minumbal ko do mongidit do boogian di inggino.
Nokowolih toi nopugas kaanto iti maso di intaannu iti bolikon.',
'loginreqtitle'                    => 'Momoguno sumuang log',
'loginreqlink'                     => 'sumuang log',
'loginreqpagetext'                 => 'Mositi ko do ki$1 do mongintong bobolikon suai.',
'accmailtitle'                     => 'Nakaatod kaatalib.',
'accmailtext'                      => "Kaatalib somporimonsoi montok [[User talk:$1|$1]] nakaatod no hilo $2.

Kaatalib montok akaun wagu milo do alanan hilo id bolikon ''[[Special:ChangePassword|pangalanan kaatalib]]'' soira do kosuang log.",
'newarticle'                       => '(Wagu)',
'newarticletext'                   => "Nakatanudko di noputan kumaa di bolikon di awu po nokosuang.
Momonsoi ko nopo do bolikon diti, timpuun do manaip id kutak siriba (intaai [[{{MediaWiki:Helppage}}|bolikon ponokodung]] montok lobi gumu kointalangan).
Nung nakaansau ko do hiti, tonsoko ot butang '''gumuli''' id pogigihumnu.",
'anontalkpagetext'                 => "----''Iti nopo nga bolikon pogibabarasan montok di momomoguno poinlisok it awu poh nokopomonsoi do takaun, toi it awu momoguno dilo.
Mantad dilo, asansagan yahai do poposurat numbur kinoyonon IP do mongintutun dau.
Kinoyonon IP pogialasan do pipiro momomoguno.
Nung momomoguno koh do ingaa ngaran om karamit koh do komin di awu kapadan, mangai [[Special:UserLogin/signup|wonsoyo takaun]] toi [[Special:UserLogin|sumuang log]] do magalai kounsuhan di momomoguno suai di tingaa ngaran.''",
'noarticletext'                    => 'Maso po do ingaa tik id bolikon diti.
Milo ko nogi do [[Special:Search/{{PAGENAME}}|mogihum do tuluhon bolikon diti]] id bolikon suai,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} mogihum kokomoi log-log],
toi [{{fullurl:{{FULLPAGENAME}}|action=edit}} mongidit bolikon diti]</span>.',
'noarticletext-nopermission'       => 'Maso po do ingaa tik id bolikon diti.
Milo ko nogi do [[Special:Search/{{PAGENAME}}|mogihum do tuluhon bolikon diti]] id bolikon suai, toi
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} mogihum kokomoi log-log] </span>.',
'userpage-userdoesnotexist'        => 'Akaun momomoguno "<nowiki>$1</nowiki>" awu nokorijisto.
Mangai intangai nung mumang ko pomonsoi/mongidit do bolikon diti.',
'userpage-userdoesnotexist-view'   => 'Akaun momomoguno "$1" awu po nokorijisto.',
'blocked-notice-logextract'        => 'Maso do nantaban momomoguno diti.
Riporon id siriba kokomoi nantaban di tohuri no:',
'clearyourcache'                   => "'''Soroho:''' Opongoh do pogompi, mangai  pawayao dangkob pogigihumnu do mongintong di nopingalanan.
'''Firefox / Safari:''' Pointodos ''Shift'' maso do mongotik ''Reload'', toi piandadon mononsok ''Ctrl-F5'' toi ''Ctrl-R'' (''⌘-R'' id Mac);
'''Google Chrome:''' Todoso ''Ctrl-Shift-R'' (''⌘-Shift-R'' id Mac)
'''Internet Explorer:''' Todoso ''Ctrl'' maso do mongotik ''Refresh,'' toi tonsoko ''Ctrl-F5''
'''Opera:''' Imuhawai id dangkob  ''Tools → Preferences''",
'usercssyoucanpreview'             => "'''Tutuduk:''' Momoguno do \"{{int:showpreview}}\" butang do mongumbal CSS kawawagunu pogulu do popogompi.",
'userjsyoucanpreview'              => "'''Tutuduk:''' Momoguno do \"{{int:showpreview}}\" butang do mongumbal JawaSikrip kawawagunu pogulu do popogompi.",
'usercsspreview'                   => "'''Soroho no do mongintong kono tomod diti CSS momogunonu.'''
'''Awu po nokogompi iti!'''",
'userjspreview'                    => "'''Soroho no do mongintong kono tomod diti JawaSikrip momogunonu.'''
'''Awu po nokogompi iti!'''",
'sitecsspreview'                   => "'''Soroho no do mongintong kono tomod diti CSS.'''
'''Awu po nokogompi iti!'''",
'sitejspreview'                    => "'''Soroho no do mongintong kono tomod diti kod JawaSikrip.'''
'''Awu po nokogompi iti!'''",
'userinvalidcssjstitle'            => "'''Pomisunudan:''' Ingaa kulit do \"\$1\".
Bobolikon pinudali .css om .js momoguno do pimato tokoro, miagal pomitanan {{ns:user}}:Foo/vector.css sobaagi do ponuli di {{ns:user}}:Foo/Vector.css.",
'updated'                          => '(Noinwoguan)',
'note'                             => "'''Pasoniba:'''",
'previewnote'                      => "'''Soroho no do iti nopo nga kopongintangan toomod.'''
Awu po moti nokogompi iri nopingalanannu!",
'previewconflict'                  => 'Miagal no diti pongitanan do tik id boogian kawas kutak pongiditan tik nung pilionnu do popogompi.',
'session_fail_preview'             => "'''Siou! Awu di dahai opongoh niditannu gisom no do natagakan data.'''
Mangai umbalai kawagu.
Nung maso do awu milo, umbalai [[Special:UserLogout|lumabus log]] om sumuang log kawagu.",
'session_fail_preview_html'        => "'''Siou! Awu di dahai opongoh niditannu gisom no do natagakan data.'''

''Sasabab no do iti {{SITENAME}} haro HTML mata di poimpasi, pongitanan diti kipoinlisok magalai do gurumpuanan JawaSikrip''

'''Nung niditan diti nopo nga otopot, maai umbalai kawagu.'''
Nung maso do awu milo, umbalai [[Special:UserLogout|lumabus log]] om sumuang log kawagu.",
'edit_form_incomplete'             => "'''Pipiro boogian poom niditan awu nokorikot hilo id monunurung, gulio momiri di niditannu tondum ogoris om umbalan kawagu.'''",
'editing'                          => 'Mongidit $1',
'editingsection'                   => 'Mongidit $1 (boogian)',
'editingcomment'                   => 'Mongidit $1 (boogian wagu)',
'editconflict'                     => 'Niditan mikutuk: $1',
'yourtext'                         => 'Tiiknu',
'storedversion'                    => 'Popogompi sinimakan',
'nonunicodebrowser'                => "'''Pononsunudan: Pogigihumnu okon ko unikod komplaion.'''
Iso panalasaian id kinoyonon it papasaga dia do otingolig mongidit bobolikon: pimato okon-ASCII maan pokitono id kutak mongidit sobaagi do tongokod pihopodomonom.",
'editingold'                       => "'''Pononsunudan: Mongidit ko di sinimakan nokodori do bolikon diti.'''
Nung pogompion nu iti, nunu nopo it nopingalanan mantad po do sinimakan nga atagak.",
'yourdiff'                         => 'Pisuaian',
'copyrightwarning'                 => "Soroho no do oinsanan toluod kumaa {{SITENAME}} nopo nga polobuson id suang $2 (intangai kointalangan $1).
Nung awu ko mumang di sinuratannu do pingiditan om popintikidon kumaa ginumuan, kada nogi pootodo do hiti.<br />
Mangakaun ko nogi do sinuratannu iti mopori, toi dinalin iri mantad domin ginumuan toi miagal di poimbibas ot pinogonuan.
'''Kada paatod kinaraja di kisanganuwonsoi do aiso kasagaan!'''",
'copyrightwarning2'                => "Soroho no do oinsanan toluod kumaa {{SITENAME}} milo iditon, simbanan, om iduon do mononoluod suai.
Nung awu ko mumang di sinuratannu do pingiditan kada nogi pootodo do hiti.<br />
Mangakaun ko nogi do sinuratannu iti mopori, toi dinalin iri mantad domin ginumuan toi miagal di poimbibas ot pinogonuan. (intaai $1 montok kointalangan).
'''Kada paatod kinaraja di kisanganuwonsoi do aiso kasagaan!'''",
'templatesused'                    => '{{PLURAL:$1|Pongomitan|Pongo-ngomintan}} gunoon id bolikon diti:',
'templatesusedpreview'             => '{{PLURAL:$1|Pongomitan|Pongo-ngomintan}} gunoon id pongitanan diti:',
'templatesusedsection'             => '{{PLURAL:$1|Pongomitan|Pongo-ngomintan}} gunoon id boogian diti:',
'template-protected'               => '(tingoligai)',
'template-semiprotected'           => '(noumoligan)',
'hiddencategories'                 => 'Bolikon diti songkoruhang do {{PLURAL:$1|1 katogori poinlisok|$1 kakatogori poinlisok}}:',
'nocreatetitle'                    => 'Momonsoi bolikon wagu pinatagal',
'nocreatetext'                     => '{{SITENAME}} tinagal kasagaan momonsoi bobolikon kawawagu.
Milo ko do gumuli om mongidit di bolikon poinsuang, toi ko [[Special:UserLogin|sumuang log toi momonsoi do takaun.]].',
'nocreate-loggedin'                => 'Ingaa kasagaannu do momonsoi bobolikon wagu.',
'sectioneditnotsupported-title'    => 'Boogian mongidit awu nosokodung',
'permissionserrors'                => 'Nokosilap pinapasaga',
'permissionserrorstext'            => 'Awu ko pasagaon do momonsoi miagal dilo, tu {{PLURAL:$1|sabab|sasabab no}} do:',
'permissionserrorstext-withaction' => 'Awu ko pasagaon do $2, {{PLURAL:$1|sabab|sasabab no}} do:',
'recreate-moveddeleted-warn'       => "'''Kapanansarahan: Koponugut koh do momudali di bolikon do nopugas.'''

Pomusarahai poh koti pogulu do potilombusonnu do mongitit toi monimban.
Log pinomugasan pinotangoi do hiti montok noh do kasanangannu.",
'moveddeleted-notice'              => 'Nopugas no bolikon diti. Pimomugasan om log pinowolihon do bolikon pinosodia id siriba montok riporon.',
'log-fulllog'                      => 'Intaai log poimponu',
'edit-hook-aborted'                => 'Niditan pinaratu do kakait.
Ingaa kointalangan diri.',
'edit-gone-missing'                => 'Awu noinwoguan bolikon.
Miagal do nopugas iti.',
'edit-conflict'                    => 'Niditan mikutuk.',
'edit-no-change'                   => 'Pinologos niditannu, tu ingaa nopingalanan id tik.',
'edit-already-exists'              => 'Awu owonsoi bolikon kawawagu.
Haro no do pinsuang.',

# Parser/template warnings
'expensive-parserfunction-warning'        => "'''Pomisunudan:''' Kisuang bolikon diti do nosontob ogumu kogunoon lolohou parsor.

It should have less than $2 {{PLURAL:$2|call|calls}}, there {{PLURAL:$1|is now $1 call|are now $1 calls}}.",
'post-expand-template-inclusion-warning'  => "'''Panansarahan:''' Pomitanan pinohompit kalabai tukuran.
Pipiro pomitanan polobuson.",
'post-expand-template-inclusion-category' => 'Bobolikon kohompit pomitanan kolabai tukuran',
'post-expand-template-argument-warning'   => "'''Kapanansarahan:''' Kisuang do sokukuri do iso pogibabarasan id pomitanan diti ii koponginggayo do suang. Nadaan noh pogibabarasan diti.",
'post-expand-template-argument-category'  => 'Yadaan bolikon dii kipibarasan kokomoi do pomitanan.',

# History pages
'viewpagelogs'           => 'Intaai tongolog do bolikon diti',
'nohistory'              => 'Ingaa susuyan niditan id bolikon diti.',
'currentrev'             => 'Sinimakan poinwagu',
'currentrev-asof'        => 'Sinimakan tohuri ontok di $1',
'revisionasof'           => 'Nosimak no di ontok',
'revision-info'          => 'Sinimakan di $2 ontok $1',
'previousrevision'       => '← Sinimakan nakalaid',
'nextrevision'           => 'Sinimakan kawawagu →',
'currentrevisionlink'    => 'Sinimakan poinwagu',
'cur'                    => 'kur',
'next'                   => 'sumuhut',
'last'                   => 'pogulu',
'page_first'             => 'koiso',
'page_last'              => 'tohuri',
'histlegend'             => "Diff selection: tandaai kutak rodiu mantad sinimakan do popibanding on tonsoko sumuang toi bamban id siriba.<br />
Lijon: '''({{int:cur}})''' = kipisuaian borsi kawawagu, '''({{int:last}})''' = kopisuaian di sinimakan nokopogulu, '''{{int:minoreditletter}}''' = niditan tokoto.",
'history-fieldset-title' => 'Pingintaai susuyan',
'history-show-deleted'   => 'Nopugas no poh',
'histfirst'              => 'Nokododori',
'histlast'               => 'Poinwawagu',
'historysize'            => '({{PLURAL:$1|1 bait|$1 babait}})',
'historyempty'           => '(ingaa)',

# Revision feed
'history-feed-title'          => 'Susuyan sinimakan',
'history-feed-description'    => 'Susuyan sinimakan do bolikon diti id wiki',
'history-feed-item-nocomment' => '$1 ontok $3 jaam $4',
'history-feed-empty'          => 'Bolikon di pinokianunu awu po poinsuang.
Nopugas no kaanto mantad id wiki, toi naalanan no ngaran.
Umbalai [[Special:Search|mogihum id wiki]] ot bolikon di kikohompiton.',

# Revision deletion
'rev-deleted-comment'         => '(nidu koinibaan niditan)',
'rev-deleted-user'            => '(nidu momomoguno)',
'rev-deleted-event'           => '(nidu log kinaraja)',
'rev-deleted-user-contribs'   => '[nidu momomoguno toi alamat IP - poilisok do minongidit di bolikon pinotoluod]',
'rev-deleted-text-permission' => "Sinimakan bolikon diti '''nopugas'''.
Kointalangan oihum id [{{fullurl:{{#Special:Log}}/delete|page={{FULLPAGENAMEE}}}} log pinugas].",
'rev-deleted-text-unhide'     => "Sinimakan bolikon diti '''nopugas'''.
Kointalangan oihum id [{{fullurl:{{#Special:Log}}/delete|page={{FULLPAGENAMEE}}}} log pinugas].
Milo ko poh do [$1 mongintong sinimakan diti] nung orohian ko.",
'rev-suppressed-text-unhide'  => "Sinimakan bolikon diti '''nalapahan'''.
Kointalangan oihum id [{{fullurl:{{#Special:Log}}/suppress|page={{FULLPAGENAMEE}}}} log nalapahan].
Milo ko nogi do [$1 mongintong sinimakan diti] nung orohian ko.",
'rev-deleted-text-view'       => "Sinimakan bolikon diti '''nopugas'''.
Milo ko do montong diti; kointalangan oihum id [{{fullurl:{{#Special:Log}}/delete|page={{FULLPAGENAMEE}}}} log pinugas].",
'rev-suppressed-text-view'    => "Sinimakan bolikon diti '''nalapahan'''.
Milo ko do montong diti; kointalangan oihum id [{{fullurl:{{#Special:Log}}/suppress|page={{FULLPAGENAMEE}}}} log nalapahan].",
'rev-deleted-no-diff'         => "Awu nu okito pisuaian diti tu iso mantad sinimakan diti '''nopugas'''.
Kointalangan oihum id [{{fullurl:{{#Special:Log}}/delete|page={{FULLPAGENAMEE}}}} log pinugas].",
'rev-suppressed-no-diff'      => "Awu ko milo do mongintong pisuaian tu iso mantad do sinimakan '''nopugas'''.",
'rev-deleted-unhide-diff'     => "Iso mantad pisuaian sinimakan bolikon diti '''nopugas'''.
Kointalangan oihum id [{{fullurl:{{#Special:Log}}/delete|page={{FULLPAGENAMEE}}}} log pinugas].
Milo ko nogi do [$1 mongintong sinimakan diti] nung orohian ko.",
'rev-suppressed-unhide-diff'  => "Iso mantad sinimakan pisuaian diti '''nalapahan'''.
Kointalangan oihum id [{{fullurl:{{#Special:Log}}/delete|page={{FULLPAGENAMEE}}}} log nalapahan].
Milo ko nogi do [$1 mongintong sinimakan diti] nung orohian ko.",
'rev-deleted-diff-view'       => "Sinimakan pisuaian diti '''nopugas'''.
Milo ko do mongintong pisuaian diti; kointalangan oihum id [{{fullurl:{{#Special:Log}}/delete|page={{FULLPAGENAMEE}}}} log pinugas].",
'rev-suppressed-diff-view'    => "Iso mantad sinimakan pisuaian diti '''nalapahan'''.
Milo ko do montong diti; kointalangan oihum id [{{fullurl:{{#Special:Log}}/suppress|page={{FULLPAGENAMEE}}}} log nalapahan].",
'rev-delundel'                => 'pokitono/lisoko',
'rev-showdeleted'             => 'popointalang',
'revisiondelete'              => 'Pugaso/pogulio sinimakan',
'revdelete-nooldid-title'     => 'Poimpalid rikoton do sinimakan',
'revdelete-nologtype-title'   => 'Awu nonuan koula-laho log',
'revdelete-nologtype-text'    => 'Awu nu pinoilo ot koula-laho log montok koimaan diti.',
'revdelete-nologid-title'     => 'Log pinosuang napalid',
'revdelete-nologid-text'      => 'Awu nu pinatantu rikoton kinaantakan log do popowonsoi kopomogunaan toi suang pointantu awu poinsuang.',
'revdelete-no-file'           => 'Pail pinotontu awu poinsuang.',
'revdelete-show-file-confirm' => 'Mongintong ko di sinimakan nopugas do pail  "<nowiki>$1</nowiki>" mantad $2 ontok $3?',
'revdelete-show-file-submit'  => 'O',
'revdelete-selected'          => "'''{{PLURAL:$2|Sinimakan pinili|Sinimakan nopili}} id [[:$1]]:'''",
'logdelete-selected'          => "'''{{PLURAL:$1|Log kinaantakan nopili|Tongolog kinaantakan it nopili}}:'''",
'revdelete-legend'            => 'Uludo pogigihum pangangantob',
'revdelete-hide-text'         => 'Polisoko sinimakan tiik',
'revdelete-hide-image'        => 'Polisoko suang pail',
'revdelete-hide-name'         => 'Lisoko nimaan om ontokon',
'revdelete-hide-comment'      => 'Lisoko koinibaan niditan',
'revdelete-hide-user'         => 'Lisoko ngaranmoguno mongingidit/kinoyonon IP',
'revdelete-hide-restricted'   => 'Polosodo data mantad mandur om nogi wokon',
'revdelete-radio-same'        => '(kada alanai)',
'revdelete-radio-set'         => 'O',
'revdelete-radio-unset'       => 'Awu',
'revdelete-suppress'          => 'Polosodo data mantad mandur om nogi wokon',
'revdelete-unsuppress'        => 'Iduon pangantaban om pogogompi sinimakan',
'revdelete-log'               => 'Sabab:',
'revdelete-submit'            => 'Pokionuo pinili {{PLURAL:$1|sinimakan|tongosinimakan}}',
'revdelete-success'           => "'''Kokitanan sinimakan nopinwoguan.'''",
'revdelete-failure'           => "'''Kokitanan sinimakan awu milo inwoguan:'''
$1",
'logdelete-success'           => "'''Nakasain kokitanan log.'''",
'logdelete-failure'           => "'''Kokitanan log di awu milo posoinon:'''
$1",
'revdel-restore'              => 'alanai pongitaanan',
'revdel-restore-deleted'      => 'sinimakan nopugas',
'revdel-restore-visible'      => 'sinimakan tokito',
'pagehist'                    => 'Susuyan bolikon',
'deletedhist'                 => 'Susuyan nopugas',
'revdelete-hide-current'      => 'Nokosilap popolisok kakamot ditadau $2, $1: iti no sinimakan wagu.
Awu milo polisokon.',
'revdelete-show-no-access'    => 'Nokosilap popokito kakamot ditadau $2, $1: natandaan iti do "pogoduhan".
Ingaa kasagaannu do maya dilo.',
'revdelete-modify-no-access'  => 'Nokosilap monimban kakamot ditadau $2, $1: natandaan iti do "pogoduhan".
Ingaa kasagaannu do maya dilo.',
'revdelete-modify-missing'    => 'Nokosilap monimban kakamot ID $1: natagak mantad databing!',
'revdelete-no-change'         => "'''Pononsunudan:''' kakamot ditadau $2, $1 nopokionuan no do nuludan  kokitanan.",
'revdelete-concurrent-change' => 'Nokosilap monimban kakamot ditadau $2, $1: nokopokito do naalanan no do sosongulun kawagu di maso ko do mumbal monimban dilo.
Maai intaai tongolog.',
'revdelete-only-restricted'   => 'Nokosilap popolisok do kakamot di $2, $1: awu ko milo do popolosod kakamot mantad kokitanai di mandur nung awu po nokopomili iso mantad pomilian kokitanai.',
'revdelete-reason-dropdown'   => '*Sasabab do pugason
** Awu katanud kooturan kuasamonsupu
** Pail ahaltinan di awu kosudong
** Ngaranmoguno di awu kosudong
** Kopoilaan di mongindaraat do wokon',
'revdelete-otherreason'       => 'Sabab suai/poinsungku:',
'revdelete-reasonotherlist'   => 'Sabab suai',
'revdelete-edit-reasonlist'   => 'Idito sasabab pinugas',
'revdelete-offender'          => 'Sinimakan monunurat:',

# Suppression log
'suppressionlog'     => 'Log nopinlasadan',
'suppressionlogtext' => 'Id siriba diti nopo nga lis di nopinpugasan om tantob kohompit suang poinlisok mantad mandur.
Intaai [[Special:BlockList|lis nantaban]] montok lis kawawagu karaja mogoduh om mangantob.',

# History merging
'mergehistory-from'                => 'Wowonod bolikon:',
'mergehistory-into'                => 'Rikoton bolikon:',
'mergehistory-list'                => 'Susuyan niditan milo pisompuruon',
'mergehistory-submit'              => 'Pisompuruo sinimakan',
'mergehistory-empty'               => 'Inggaa sinimakan do milo pisompuruon',
'mergehistory-success'             => '$3 {{PLURAL:$3|sinimakan|tongosinimakan}} montok[[:$1]] nokopisompuru noh id [[:$2]].',
'mergehistory-fail'                => 'Awu milo do pisompuruon susuyan, mangai imuriai iri bolikon om nuludan do timpu.',
'mergehistory-no-source'           => 'Wowonod bolikon $1 awu poinsuang.',
'mergehistory-no-destination'      => 'Korikoton do bolikon $1 awu poinsuang.',
'mergehistory-invalid-source'      => 'Wowonod do bolikon mositi do tuluhon di asaah.',
'mergehistory-invalid-destination' => 'Korkoton do bolikon mositi di tuluhon asaah.',
'mergehistory-autocomment'         => 'Popisompuru [[:$1]] miampai [[:$2]]',
'mergehistory-comment'             => 'Popisompuru [[:$1]] miampai [[:$2]]: $3',
'mergehistory-same-destination'    => 'Wowonod om korikoton do bolikon awu milo do miagal',
'mergehistory-reason'              => 'Sabab:',

# Merge log
'mergelog'           => 'Log pinisompuru',
'pagemerge-logentry' => 'pisompuruo [[$1]] sumuang id [[$2]] (sinimakan gisom do $3)',
'revertmerge'        => 'Kada piisoo',
'mergelogpagetext'   => 'Id siriba diti nopo nga lis kawawagu do pinisompuruan susuyan tiso-iso bolikon kumaa doid bolikon do suai.',

# Diffs
'history-title'            => 'Susuyan sinimakan do "$1"',
'difference'               => '(Pisuaian mantad sinimakan)',
'difference-multipage'     => '(Pisuaian do tongobolikon)',
'lineno'                   => 'Baris $1:',
'compareselectedversions'  => 'Popitimbang sinimakan nopili',
'showhideselectedversions' => 'Pokitono/polisoko sinimakan nopili',
'editundo'                 => 'suguto mongidit',
'diff-multi'               => '({{PLURAL:$1|Iso sinimakan pintangaan|$1 tongosinimakan pintangaan}} di {{PLURAL:$2|iso momomoguno|$2 momomoguno}} awu pokitonon)',

# Search results
'searchresults'                    => 'Kootuson nihuman',
'searchresults-title'              => 'Kootuson nihuman do "$1"',
'searchresulttext'                 => 'Mongilo ko nopo do lobi ginumu kokomoi mogigihum {{SITENAME}}, intangai [[{{MediaWiki:Helppage}}|{{int:help}}]].',
'searchsubtitle'                   => 'Minogihum ko do \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|oinsanan bolikon di kitimpuun "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|oinsanan bolikon di kitoput "$1"]])',
'searchsubtitleinvalid'            => "Mogihum ko do '''$1'''",
'titlematches'                     => 'Kopisangai tuluhon bolikon',
'notitlematches'                   => 'Aiso bolikon di kopisangai',
'textmatches'                      => 'Kopisangai tik bolikon',
'notextmatches'                    => 'Aiso tik kopiontok id bolikon',
'prevn'                            => 'poinguluon {{PLURAL:$1|$1}}',
'nextn'                            => 'sumuhut {{PLURAL:$1|$1}}',
'prevn-title'                      => 'Notoliban $1 {{PLURAL:$1|kootuson|tongokootuson}}',
'nextn-title'                      => 'Sumusuhut $1 {{PLURAL:$1|kootuson|tongokootuson}}',
'shown-title'                      => 'Pokitono $1 {{PLURAL:$1|kootuson|tongokootuson}} monikid bolikon',
'viewprevnext'                     => 'Intaai ($1 {{int:pipe-separator}} $2) ($3)',
'searchmenu-legend'                => 'Pilion ihum-ihumon',
'searchmenu-exists'                => "'''Haro no bolikon pinungaranan do \"[[:\$1]]\" hiti id wiki.'''",
'searchmenu-new'                   => "'''Pomonsoi do bolikon \"[[:\$1]]\"hiti id wiki!'''",
'searchhelp-url'                   => 'Help:Susuang',
'searchprofile-articles'           => 'Suang bobolikon',
'searchprofile-project'            => 'Tatabang om Tongobolikon purujik',
'searchprofile-images'             => 'Multimodia',
'searchprofile-everything'         => 'Nunu nopo',
'searchprofile-advanced'           => 'Poinsogulu',
'searchprofile-articles-tooltip'   => 'Ihumo id $1',
'searchprofile-project-tooltip'    => 'Ihumo id $1',
'searchprofile-images-tooltip'     => 'Ihumo montok tongopail',
'searchprofile-everything-tooltip' => 'Ihumo oinsanan suang (kohompit bobolikon bolotok)',
'searchprofile-advanced-tooltip'   => 'Pogihum momoguno pinotomod ngaran',
'search-result-size'               => '$1 ({{PLURAL:$2|1 ka|$2 ka-ka}})',
'search-result-category-size'      => '{{PLURAL:$1|1 tutumanud|$1 tongotutumanud}} ({{PLURAL:$2|1 rapang katogori|$2 tangarapang katogori}}, {{PLURAL:$3|1 pail|$3 tangapail}})',
'search-redirect'                  => '(potilombuso hilo $1)',
'search-section'                   => '(bogian $1)',
'search-suggest'                   => '$1 ot komoyonnu?',
'search-interwiki-caption'         => 'Taka do purujik',
'search-interwiki-default'         => 'Kootuson $1:',
'search-interwiki-more'            => '(lobi)',
'search-mwsuggest-enabled'         => 'miampai tua do tutok',
'search-mwsuggest-disabled'        => 'ingaa tua do tutok',
'search-relatedarticle'            => 'Kompinaian',
'searcheverything-enable'          => 'Pogihum momoguno oinsanan ngaran:',
'searchrelated'                    => 'kompinaian',
'searchall'                        => 'oinsanan',
'showingresultsheader'             => "{{PLURAL:$5|Kootuson '''$1''' of '''$3'''|Tongkootuson '''$1 - $2''' of '''$3'''}} montok '''$4'''",
'nonefound'                        => "'''Panansarahan''': Haro pipiro no kinoiyonon ngaran it ihumon maya do poinsandad.
Umbalai momogonop it ihumonnu miampai do ''all:'' mooi do oihum ot oinsanan suang (poinsuang bobolikon pogibabarasan, pomitanan wonsoi, om nunu nopo it kopiagal), toi momoguno kinoiyonon ngaran sobaagi do poninimpuun.",
'search-nonefound'                 => 'Ingaa kootuson kaagal di kuiri.',
'powersearch'                      => 'Pogigihum poimogot',
'powersearch-legend'               => 'Pogigihum poimogot',
'powersearch-ns'                   => 'Pogihum momoguno ngaran:',
'powersearch-redir'                => 'Liniisan nopotilombus',
'powersearch-field'                => 'Ihumo ot',
'powersearch-togglelabel'          => 'Imuriai:',
'powersearch-toggleall'            => 'Oinsanan',
'powersearch-togglenone'           => 'Ingaa',
'search-external'                  => 'Pogihum poinsoliwan',
'searchdisabled'                   => 'Pogigihum maya{{SITENAME}} nopisok.
Milo ko mogihum maya Googol do daamot.
Imurai no do indik suang diti {{SITENAME}} nopo nga nokolipas.',

# Quickbar
'qbsettings'               => 'Barposikap',
'qbsettings-none'          => 'Ingaa',
'qbsettings-fixedleft'     => 'Pogolibango',
'qbsettings-fixedright'    => 'Pawanano',
'qbsettings-floatingleft'  => 'Posoibaho gibang',
'qbsettings-floatingright' => 'Posoibaho wanan',

# Preferences page
'preferences'                 => 'Pipilion',
'mypreferences'               => 'Pipilion',
'prefs-edits'                 => 'Ginumu niditan:',
'prefsnologin'                => 'Amu nokolog sumuang',
'changepassword'              => 'Alanai kaatalib',
'prefs-skin'                  => 'Kulit',
'skin-preview'                => 'Kokitanan',
'datedefault'                 => 'Ingaa komoisoon',
'prefs-datetime'              => 'Haribulan om timpu',
'prefs-rc'                    => 'Wagu kaalanai',
'prefs-resetpass'             => 'Alanai kaatalib',
'prefs-changeemail'           => 'Alanai porikatan surat-i',
'prefs-rendering'             => 'Kowoyowoyoon',
'saveprefs'                   => 'Pogompio',
'resetprefs'                  => 'Pugaso nalanan awu nogompi',
'searchresultshead'           => 'Ihumo',
'servertime'                  => 'Timpu mamamalayan:',
'guesstimezone'               => 'Gunoo pinatantu do lalayagku',
'timezoneregion-africa'       => 'Aprika',
'timezoneregion-america'      => 'Amirika',
'timezoneregion-antarctica'   => 'Antartika',
'timezoneregion-arctic'       => 'Artik',
'timezoneregion-asia'         => 'Asia',
'timezoneregion-atlantic'     => 'Karahatan Atlantik',
'timezoneregion-australia'    => 'Astaralia',
'prefs-searchoptions'         => 'Ihumo',
'prefs-namespaces'            => 'Ponuratan ngaran',
'youremail'                   => 'Surat-i:',
'yourrealname'                => 'Ngaran otopot:',
'prefs-help-email'            => 'Surat-i pasagaon do momili, nga gunoon iti montok do popoguli do kaatalib, nung olihuannu kaatalib',
'prefs-help-email-others'     => 'Milo nogi do momili ko nung mokiromut do tulun suai momoguno maya do noputan surat-i id bolikon momogunonu toi id bolikon bolotok. Awu iy pokitonon surat-i nu kumaa do momomoguno suai.',
'prefs-advancedediting'       => 'Pomilian pointilombus',
'prefs-advancedrc'            => 'Pomilian pointilombus',
'prefs-advancedrendering'     => 'Pomilian pointilombus',
'prefs-advancedsearchoptions' => 'Pomilian pointilombus',
'prefs-advancedwatchlist'     => 'Pomilian pointilombus',
'prefs-displayrc'             => 'Pomilian pongitanan',
'prefs-displaysearchoptions'  => 'Pomilian pongitanan',
'prefs-displaywatchlist'      => 'Pomilian pongitanan',
'prefs-diffs'                 => 'Pisuaian',

# User preference: email validation using jQuery
'email-address-validity-valid'   => 'Porikatan surat-i asaah',
'email-address-validity-invalid' => 'Posuango porikatan surat-i di asaah',

# User rights
'userrights'                   => 'Ponguludan don momomoguna',
'userrights-lookup-user'       => 'Uludo tinimungan momomoguno',
'userrights-user-editname'     => 'Posuango ngaranmoguno:',
'editusergroup'                => 'Idito tinimungan momomoguno',
'editinguser'                  => "Monimban kapasagaan don momomoguno '''[[User:$1|$1]]''' $2",
'userrights-editusergroup'     => 'Mongidit tinimungan momomoguno',
'saveusergroups'               => 'Pogompio tinimungan momomoguno',
'userrights-groupsmember'      => 'Tutumanud montok:',
'userrights-groupsmember-auto' => 'Tutumanud toporian montok:',

# Groups
'group-sysop' => 'Mandur',

'grouppage-sysop' => '{{ns:project}}:Mandur',

# User rights log
'rightslog' => 'Log kasagaan momomoguno',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'Idito bolikon diti',

# Recent changes
'nchanges'                        => '$1 {{PLURAL:$1|naalanan|nopingalanan}}',
'recentchanges'                   => 'Wagu kaalanai',
'recentchanges-legend'            => 'Pomilian kaalanai kawawagu',
'recentchanges-feed-description'  => 'Monousui kinosuaion kawawagu kumaa do wiki id pambababu diti.',
'recentchanges-label-newpage'     => 'Niditan diti kopomonsoi do bolikon kawawagu',
'recentchanges-label-minor'       => 'Iti nopo nga niditan tokoto',
'recentchanges-label-bot'         => 'Niditan diti winonsoi do robot',
'recentchanges-label-unpatrolled' => 'Niditan diti awu poh nosimak',
'rcnote'                          => "Iti {{PLURAL:$1|noh '''1''' nalanan|nopo '''$1''' dohuri nopingalanan}} solinaid {{PLURAL:$2|tadau|'''$2''' tadau}}, ontok di $4, jaam $5.",
'rcnotefrom'                      => "Id siriba diti pokitonon ii nopingalanan mantad '''$2''' (gisom '''$1''' ).",
'rclistfrom'                      => 'Pokitono naalanan kawawagu tumimpuun mantad $1',
'rcshowhideminor'                 => '$1 niditan tokoto',
'rcshowhidebots'                  => 'Roboto $1',
'rcshowhideliu'                   => '$1 momomoguno poinlog sinumuang',
'rcshowhideanons'                 => '$1 momomoguno awu popointutun',
'rcshowhidepatr'                  => '$1 niditan nosimak',
'rcshowhidemine'                  => '$1 niditanku',
'rclinks'                         => 'Popokito soginumu $1 kaalanai id suang $2 tadau<br />$3',
'diff'                            => 'pisuai',
'hist'                            => 'susui',
'hide'                            => 'Popolisok',
'show'                            => 'Popointalang',
'minoreditletter'                 => 'o',
'newpageletter'                   => 'W',
'boteditletter'                   => 'rb',
'rc-enhanced-expand'              => 'Pokitono kointalangan (momoguno JawaSikrip)',
'rc-enhanced-hide'                => 'Polisoko kointalangan',

# Recent changes linked
'recentchangeslinked'          => 'Kinaalanan di kohompit',
'recentchangeslinked-toolbox'  => 'Kinaalanan di kohompit',
'recentchangeslinked-title'    => "Kinowolion 'parameter' it awu noguno: $1",
'recentchangeslinked-noresult' => 'Ingaa nalanan do noputan bolikon id timpu nokomoi.',
'recentchangeslinked-summary'  => "Iti nopo nga lis kawawagu kaalanai winonsoi kumaa noputan bobolikon mantad bolikon pointantu (toi kumaa momomoguno tinansaran pointantu).
Bobolikon id [[Special:Watchlist|lis pintangannu]] nopo nga '''pinakapal'''.",
'recentchangeslinked-page'     => 'Ngaran bolikon:',
'recentchangeslinked-to'       => 'Popokito nokowolion do bobolikon nokooput kumaa dii bolikon pinatahak nogi',

# Upload
'upload'            => 'Mangaplod pail',
'uploadbtn'         => 'Mangaplod pail',
'reuploaddesc'      => 'Batalo mangaplod om gumuli hilo id poom mongaplod',
'upload-tryagain'   => 'Pootodo pongintalangan pail nomodipait',
'uploadnologin'     => 'Amu nokolog sumuang',
'uploadnologintext' => 'Pinatantu ko do [[Special:UserLogin|lumoog sumuang]] do mangaplod tangapail-pail.',
'uploadlogpage'     => 'Log poposuang',
'filedesc'          => 'Koinibaan',
'uploadedimage'     => 'poposuang "[[$1]]"',

'license'        => 'Pongolisinan:',
'license-header' => 'Pongolisinan',

# Special:ListFiles
'listfiles_search_for'  => 'Mogihum ngaran modia:',
'imgfile'               => 'pail',
'listfiles'             => 'Lis do pail',
'listfiles_thumb'       => 'Sinondulu',
'listfiles_date'        => 'Adau',
'listfiles_name'        => 'Ngaran',
'listfiles_user'        => 'Momoguno',
'listfiles_size'        => 'Tipong',
'listfiles_description' => 'pongowowoyoon',
'listfiles_count'       => 'Dolinan',

# File description page
'file-anchor-link'          => 'Pail',
'filehist'                  => 'Susuyan pail',
'filehist-help'             => 'Kotiko id kalindo / maso do mongintong di upa dilo pail ontok di timpu nokomoi.',
'filehist-deleteall'        => 'pugaso koinsanai',
'filehist-deleteone'        => 'pugaso',
'filehist-revert'           => 'gulio',
'filehist-current'          => 'timpu diti',
'filehist-datetime'         => 'Kalindo/Maso',
'filehist-thumb'            => 'Sinondulu',
'filehist-thumbtext'        => 'Kointalangan sinondulu montok borsi maso di $1',
'filehist-nothumb'          => 'Ingaa sinondulu',
'filehist-user'             => 'Momomoguno',
'filehist-dimensions'       => 'Ginayo',
'filehist-filesize'         => 'Tinipongan pail',
'filehist-comment'          => 'Kumin',
'filehist-missing'          => 'Natagak pail',
'imagelinks'                => 'Pomogunaan do pail',
'linkstoimage'              => 'Iti kiharo {{PLURAL:$1|bolikon poingoput|$1 bobolikon poingoput}} id pail diti:',
'nolinkstoimage'            => 'Ingaa bobolikon it poingoput id pail diti.',
'morelinkstoimage'          => 'Intaai [[Special:WhatLinksHere/$1|tongotoput]] pail diti.',
'sharedupload'              => 'Pail diti mantad $1 om kaanto nogi do gunoon doid purujik suai.',
'sharedupload-desc-there'   => 'Pail diti mantad $1 om gunoon nogi do tongopurujik suai.
Intaai [$2 bolikon pongowowoyoon pail] montok pongintalangan.',
'sharedupload-desc-here'    => 'Pail diti mantad $1 om milo do gunoon id purujik suai.
Kointalangan dilo [$2 kointalangan pail] okito id siriba.',
'uploadnewversion-linktext' => 'Pasakayo borsi kawawagu do pail diti',

# Random page
'randompage' => 'Songkobolikanan',

# Statistics
'statistics' => 'Runumboboyo',

'disambiguationspage' => 'Template:patarango',

# Miscellaneous special pages
'nbytes'        => '$1 {{PLURAL:$1|bait|babait}}',
'nmembers'      => '$1 {{PLURAL:$1|koombolutan|tongokoombolutan}}',
'prefixindex'   => 'Oinsanan bolikan di kiponimpuunan',
'usercreated'   => '{{GENDER:$3|Created}} ontok $1 di jaam $2',
'newpages'      => 'Bobolikon wagu',
'move'          => 'Poundoliho',
'movethispage'  => 'Poundoliho iti bolikon',
'pager-newer-n' => '{{PLURAL:$1|kawawagu 1|kawawagu $1}}',
'pager-older-n' => '{{PLURAL:$1|nokodori 1|nokodori $1}}',

# Book sources
'booksources'               => 'Nantadon buuk',
'booksources-search-legend' => 'Ihumo tadon buuk',
'booksources-go'            => 'Ibok',

# Special:Log
'specialloguserlabel' => 'Momoguno:',
'log'                 => 'Tongolog',

# Special:AllPages
'allpages'          => 'Oinsanan bolikon',
'alphaindexline'    => '$1 gisom $2',
'nextpage'          => 'Bolikon sumuhut ($1)',
'prevpage'          => 'Bolikon nakatalib $1',
'allpagesfrom'      => 'Pokitono bobolikon tinimpuun do:',
'allpagesto'        => 'Pokitono bobolikon nopupusan do:',
'allarticles'       => 'Oinsanan bobolikon',
'allinnamespace'    => 'Oinsanan bobolikon ($1 poiyanan-ngaran)',
'allnotinnamespace' => 'Oinsanan bobolikon (awu poinsuang $1 poiyanan-ngaran)',
'allpagesprev'      => 'Nokopogulu',
'allpagesnext'      => 'kaagu',
'allpagessubmit'    => 'Ibok',
'allpagesprefix'    => 'Pokitono bolikon di kitinimpuunon:',
'allpages-bad-ns'   => '{{SITENAME}} aiso pinungaranan do "$1"',

# Special:Categories
'categories'                  => 'Kakatogori',
'categoriesfrom'              => 'Pokitono kakatogori tinimpuun do:',
'special-categories-sort-abc' => 'uludo mompimato',

# Special:DeletedContributions
'deletedcontributions'             => 'Pugaso pinototoluod do momoguno',
'deletedcontributions-title'       => 'Pugaso pinototoluod do momoguno',
'sp-deletedcontributions-contribs' => 'Totoluod',

# Special:LinkSearch
'linksearch'      => 'Noputan poinsoliwan',
'linksearch-ns'   => 'Ponuratan ngaran:',
'linksearch-ok'   => 'Ihumo',
'linksearch-line' => '$1 toput mantad $2',

# Special:Log/newusers
'newuserlogpage' => 'Log pinamansaian momomoguno',

# Special:ListGroupRights
'listgrouprights-members' => '(lis do kinoruhangan)',

# Email user
'emailuser' => 'Surat-i momomoguno diti',

# Watchlist
'watchlist'         => 'Lis piintanganku',
'mywatchlist'       => 'Lis piintanganku',
'watchlistfor2'     => 'Montok $1 $2',
'addedwatchtext'    => "Bolikon \"[[:\$1]]\" nokoruhang no id [[Special:Watchlist|lis piintangannu]].
Kinaalanan id bolikon om kinoruhangan bolikon bolotok diti do maso dumontol maan posurato do hiti, om bolikon diti pokitonon do '''akapal''' id [[Special:RecentChanges|lis wagu kaalanai]] do poposikap mongintutun.",
'removedwatchtext'  => 'Bolikon "[[:$1]]" noidu no mantad [[Special:Watchlist|lis piintangannu]].',
'watch'             => 'Mongintong',
'watchthispage'     => 'Piintong bolikon diti',
'unwatch'           => 'Awu intangan',
'unwatchthispage'   => 'Tingkod do mongintong',
'watchlist-details' => '{{PLURAL:$1|$1 bolikon|$1 bobolikon}} id lis piintangannu, bobolikon bolotok awu pinosuang.',
'wlshowlast'        => 'Pokitono dohuri $1 jaam $2 tadau $3',
'watchlist-options' => 'Pomilian lis piintangan',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Piintong...',
'unwatching' => 'Awu piintong...',

# Delete
'deletepage'            => 'Pugaso bolikon',
'confirmdeletetext'     => 'Pugasonnu ot bolikon diti miampai toinsanan susuyan tangadata.
Mangai potontuo do mimang iti no komoyonnu om karati ko do kotutukon, om winonsoinu iti katanud do  [[{{MediaWiki:Policy-url}}|kopitimbangan]].',
'actioncomplete'        => 'Nopongoh',
'actionfailed'          => 'Nantaban karaja',
'deletedtext'           => '"$1" nopugas nodi.
Intaai $2 montok ruputan di wagu pinugas.',
'dellogpage'            => 'Log pinimpugasan',
'deletecomment'         => 'Sabab:',
'deleteotherreason'     => 'Sabab suai/poinsungku:',
'deletereasonotherlist' => 'Sabab suai',

# Rollback
'rollbacklink' => 'poturug guli',

# Protect
'protectlogpage'              => 'Log noumoligan',
'protectedarticle'            => 'notingoligan "[[$1]]"',
'modifiedarticleprotection'   => 'alanai tingkat pongumoligan montok "[[$1]]"',
'protectcomment'              => 'Sabab:',
'protectexpiry'               => 'Nokolubo:',
'protect_expiry_invalid'      => 'Timpu kolubo awu koontok.',
'protect_expiry_old'          => 'Timpu kolubo nopo nga notoliban no.',
'protect-text'                => "Milo ko do mongintong om mongolon tingkat tingolig montok bolikon diti '''$1'''.",
'protect-locked-access'       => "Ingaa kasagaan do akaunnu do mongolon tingkat tingolig bolikon. Iti no nuludan sandad montok bolikon '''$1'''.",
'protect-cascadeon'           => 'Bolikon diti maso po do notingoligan tu poinsuang iti {{PLURAL:$1|bolikon, it kisuang|bobolikon, kisuang}} tingolig kasading poimposik.
Milo ko nogi do mongolon tingkat tingolig diti, nga ingaa it kosimbanon montok tingolig kasading.',
'protect-default'             => 'Pasagao oinsanan momomoguno',
'protect-fallback'            => 'Momoguna kasagaan "$1"',
'protect-level-autoconfirmed' => 'Antabai kawawagu om momomoguno awu nokorijisto',
'protect-level-sysop'         => 'Mongungulud nopo',
'protect-summary-cascade'     => 'kasading',
'protect-expiring'            => 'kolubo ontok $1 (UTC)',
'protect-cascade'             => 'Umoligai bobolikon poinghompit id bolikon diti (tingolig kasading)',
'protect-cantedit'            => 'Awu ko kopongolon do tingkat tingolig id bolikon diti, tu ingaa kasagaan nu do monimban diti.',
'restriction-type'            => 'Kasagaan:',
'restriction-level'           => 'Tingkat pangantaban',

# Undelete
'undeletelink'     => 'intangai/pogompio',
'undeleteviewlink' => 'intaai',

# Namespace form on various pages
'namespace'      => 'Ponuratan ngaran',
'invert'         => 'Posolimpado pinilion',
'blanknamespace' => '(Poingayo)',

# Contributions
'contributions'       => 'Pinotoluod do momomoguno',
'contributions-title' => 'Pinotoluod momomoguno montok $1',
'mycontris'           => 'Pinotoluodku',
'contribsub2'         => 'Montok $1 ($2)',
'uctop'               => '(id kaas)',
'month'               => 'Mantad tulan (om di tulaan po):',
'year'                => 'Mantad toun (om di touun po):',

'sp-contributions-newbies'  => 'Pokitono pinotoluod di takaun kawawagu nopo.',
'sp-contributions-blocklog' => 'antabai log',
'sp-contributions-uploads'  => 'poposuang',
'sp-contributions-logs'     => 'tongolog',
'sp-contributions-talk'     => 'bolotok',
'sp-contributions-search'   => 'Ihumo pinotoluod',
'sp-contributions-username' => 'Kinoyonon IP toi momomoguno:',
'sp-contributions-toponly'  => 'Pokitono nititan kawawagu di nobiri.',
'sp-contributions-submit'   => 'Ihumo',

# What links here
'whatlinkshere'            => 'Nunu poingoput hiti',
'whatlinkshere-title'      => 'Bolikon di poingoput id "$1"',
'whatlinkshere-page'       => 'Bolikon:',
'linkshere'                => "Bolikon diti poingoput kumaa id  '''[[:$1]]''':",
'nolinkshere'              => "Ingaa bolikon poingoput id '''[[:$1]]'''.",
'isredirect'               => 'bolikon pinotilombus',
'istemplate'               => 'alanai',
'isimage'                  => 'noputan do upa',
'whatlinkshere-prev'       => '{{PLURAL:$1|nokopogulu|duluon $1}}',
'whatlinkshere-next'       => '{{PLURAL:$1|tohuri|dohuri $1}}',
'whatlinkshere-links'      => '← noputan',
'whatlinkshere-hideredirs' => '$1 pinotilombus',
'whatlinkshere-hidetrans'  => '$1 pangalanan',
'whatlinkshere-hidelinks'  => '$1 noputan',
'whatlinkshere-hideimages' => '$1 noputan gambar',
'whatlinkshere-filters'    => 'Gaganon',

# Block/unblock
'blockip'                  => 'Antabai momomoguno',
'ipboptions'               => '2 jaam:2 hours, sangadau:1 day,3 tadau:3 days, sominggu:1 week,2 minggu:2 weeks,sombulan:1 month,3 tulan:3 months,6 tulan:6 months,sontoun:1 year,inointob:infinite',
'unblockip'                => 'Kada antabai momomoguno',
'unblockiptext'            => 'Gunoo poom  id siriba do poposuang kasagaan monurat montok do kinoyonon IP toi ngaran momomoguno di pogulu naantaban.',
'ipusubmit'                => 'Iduo pinangantob diti',
'unblocked'                => '[[User:$1|$1]] naantaban no.',
'unblocked-id'             => 'Noidu no tantob di $1',
'ipblocklist'              => 'Antabai momomoguno',
'ipblocklist-legend'       => 'Ihumo momomoguno naantaban',
'ipblocklist-submit'       => 'Ihumo',
'blocklink'                => 'antabai',
'unblocklink'              => 'iduo tantob',
'change-blocklink'         => 'alanai nantaban',
'contribslink'             => 'panahak',
'blocklogpage'             => 'Antabai log',
'blocklogentry'            => 'naantaban [[$1]] gisom $2 $3',
'unblocklogentry'          => 'naantaban $1',
'block-log-flags-nocreate' => 'awu milo momonsoi akaun',

# Move page
'movepagetext'     => "Momoguno do poom id siriba diti kopongolon do ngaran bolikon om popoundalih oinsanan susuyan data dau in ngaran kawawagu.
Tuluhon dau mantad potilombuson id nokoolihon tuluhon bolikon  kawawagu.
Milo ko nogi do mongodoropi di nokoolihon di momoguno do tuluhon antad maya do kangkaraja oporian.
Mada ko nopo do momili dilo, simakon no poingonop it [[Special:DoubleRedirects|nosugut]] toi 
[[Special:BrokenRedirects|lombuson naraag]].
Kitonggungan ko do momorisa di noputan do pointopot ot korikoton.

Intaai no do bolikon '''awu''' kopinda nung haro no bolikon id tuluhon kawawagu diri, suai ko ingaa suang toi kilinombuson om ingaa susuyan niditan di pogulu poh.
Komoyon do milo ko nogi do mongolon ngaran bolikon gumuli hilo tiyonon diri nung kosilap ko om awu ko nogi kapamalapau di bolikon nokosuang mantad.


'''Pansarahan!'''
Milo iti do kawalih tagayo om awu nopoimanan montok bolikon di aramaiti;
kalansanan do karati ko kopio do nunu kotutukon do karajanu pogulu po do potilombuson.",
'movepagetalktext' => "Bolikon bolotok it kokomoi maan popimporio do poundalih piampaion dilo '''awu kohompit:'''
* Iso bolikon bolotok it kisuang om kiharo it pinungaranan do wagu, toi
* maai pugaso tanda rait id kutak siriba diti.

Id kis dilo, mositi do momoguno do karalan-ralanon longonon nung popindaon toi posungkuonnu ot bolikon dilo.",
'movearticle'      => 'Popinda bolikon:',
'newtitle'         => 'Mongoi tuluhon kawawagu:',
'move-watch'       => 'Intangai bolikon wowonod om bolikon dimpoton',
'movepagebtn'      => 'Popinda bolikon',
'pagemovedsub'     => 'Nopongoh popinda',
'movepage-moved'   => '\'\'\'"$1" nokowalih do hilo "$2"\'\'\'',
'articleexists'    => 'Kibolikon no do momoguno ngaran dilo, toi ngaran di nopili awu pasagaon.
Pilio ngaran suai.',
'talkexists'       => "'''Nakaalih no bo daa bolikon dilo, nga it bolikon bolotok awu di kaalih tu kopiirad ot judul di poinsuang mantad.
Maai no longono do posungku.'''",
'movedto'          => 'powolihon hilo',
'movetalk'         => 'Pooliho bolikon bolotok di poingompinai',
'movelogpage'      => 'Poundoliho log',
'movereason'       => 'Sabab:',
'revertmove'       => 'gulio',

# Export
'export' => 'Poposoliwan bobolikon',

# Namespace 8 related
'allmessagesname'    => 'Ngaran',
'allmessagesdefault' => 'Tik pason sandad',

# Thumbnails
'thumbnail-more'  => 'Ingayaai',
'thumbnail_error' => 'Nokosilap momonsoi pongitanan sondulu: $1',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Bolikon mongogunonu',
'tooltip-pt-mytalk'               => 'Bolikon pibabarasannu',
'tooltip-pt-preferences'          => 'Komoisoonnu',
'tooltip-pt-watchlist'            => 'Lis do bobolikon di maannu piintaai do alanan',
'tooltip-pt-mycontris'            => 'Lis di pinototoluodnu',
'tooltip-pt-login'                => 'Alapon ko do mongolog sumuang; poingkuro po nga, okon ih ko awajip',
'tooltip-pt-logout'               => 'Lumabus log',
'tooltip-ca-talk'                 => 'Pogigibarasan kokomoi do suang bolikon',
'tooltip-ca-edit'                 => 'Kasagaan ko nogi do mongidit diti bolikon. Gunoo no butang kointalangandulu pogulu po do popoopion',
'tooltip-ca-addsection'           => 'Potimpuuno bogian kakawgu',
'tooltip-ca-viewsource'           => 'Bolikon diti notingoligan.
Milo ko mongintong do wowonod',
'tooltip-ca-history'              => 'Tolibai sinimakan id bolikon diti',
'tooltip-ca-protect'              => 'Tingoligai iti bolikon',
'tooltip-ca-delete'               => 'Pugaso iti bolikon',
'tooltip-ca-move'                 => 'Poundoliho iti bolikon',
'tooltip-ca-watch'                => 'Poruhango bolikon diti id lis piintangannu',
'tooltip-ca-unwatch'              => 'Iduo bolikon diti id lis piintangannu',
'tooltip-search'                  => 'Ihumo id {{SITENAME}}',
'tooltip-search-go'               => 'Ongoi hilo bolikon di kingaran poingonop nung haro do poinsurat',
'tooltip-search-fulltext'         => 'Ihumo bolikon do tik diti',
'tooltip-p-logo'                  => 'Tombuluyo hilo natadon tagayo',
'tooltip-n-mainpage'              => 'Tombuluyo hilo natadon tagayo',
'tooltip-n-mainpage-description'  => 'Tombuluyo hilo natadon tagayo',
'tooltip-n-portal'                => 'Kokomoi do purujik, nunu milo do maannu, hinonggo pogihuman do kuo',
'tooltip-n-currentevents'         => 'Ihumo kointalangan dolikudon kokomoi kinaantakan poinwawagu',
'tooltip-n-recentchanges'         => 'Lis di wagu koolon id suang wiki',
'tooltip-n-randompage'            => 'Posuango sorononggo bolikon',
'tooltip-n-help'                  => 'Tampat do pogihuman',
'tooltip-t-whatlinkshere'         => 'Lis koinsanai bolikon wiki it poingoput do hiti',
'tooltip-t-recentchangeslinked'   => 'Kaalanai kawawagu id bolikon nokooput id bolikon diti',
'tooltip-feed-rss'                => 'Papababu RSS id bolikon diti',
'tooltip-feed-atom'               => 'Papababu Atom id bolikon diti',
'tooltip-t-contributions'         => 'Intangai lis do pinototoluod do momomoguno diti',
'tooltip-t-emailuser'             => 'Ponurat-i kumaa do momomoguno diti',
'tooltip-t-upload'                => 'Mangaplod pail',
'tooltip-t-specialpages'          => 'Lis koinsanai bolikon suaikowokon',
'tooltip-t-print'                 => 'Kodolinan milo pirinon hiti id bolikon',
'tooltip-t-permalink'             => 'Toput pointatap do hiti id bolikon sinimak',
'tooltip-ca-nstab-main'           => 'Intaai it suang bolikon',
'tooltip-ca-nstab-user'           => 'Intaai bolikon do momomoguno',
'tooltip-ca-nstab-special'        => 'Iti nopo nga bolikon pinatantu, awu ko milo do mimpopori mongidit',
'tooltip-ca-nstab-project'        => 'Intaai bolikon do purujik',
'tooltip-ca-nstab-image'          => 'Intaai ot bolikon pail',
'tooltip-ca-nstab-template'       => 'Intaai pomitanan',
'tooltip-ca-nstab-category'       => 'Intaai koinansar bolikon',
'tooltip-minoredit'               => 'Tondukai do niditan tokoto iti',
'tooltip-save'                    => 'Umoligai iri nalanannu',
'tooltip-preview'                 => 'Pongitanan di nalanannu, maai no gunoo iti pogulu do popogompi niditan.',
'tooltip-diff'                    => 'Pokitono nongo iri nalanan winonsoinu id tik',
'tooltip-compareselectedversions' => 'Intaai ot pisuaian dilo godu-duo sinimakan nopili id bolikon diti',
'tooltip-watch'                   => 'Poruhango bolikon diti id lis piintangannu',
'tooltip-upload'                  => 'Timpuun mangaplod',
'tooltip-rollback'                => '"Pogulio kawagu" mongolon di niditan do bolikon diti tumanud di doun mononoluod tohuri maya do iso kotik',
'tooltip-undo'                    => '"Pogulio" mongolon diti niditan om mongukab poom idito id kointalangan do pongitanan no tomod. Ahal diti papasaga do mongoruhang kumin toniba.',
'tooltip-summary'                 => 'Posurato koinibaan',

# Attribution
'others'      => 'susuai',
'siteusers'   => '{{SITENAME}} {{PLURAL:$2|momoguno|momomoguno}} $1',
'anonusers'   => '{{SITENAME}} aisongaran {{PLURAL:$2|momoguno|momomoguno}} $1',
'creditspage' => 'Pounsikou do bolikon',
'nocredits'   => 'Ingaa ih ot ahal kokomoi di pinopotoluod do bolikon diti.',

# Browsing diffs
'previousdiff' => '← Niditan nakalaid',
'nextdiff'     => 'Niditan kawawagu →',

# Media information
'file-info-size' => '$1 × $2 pipisil, sais pail: $3, nuludan MIME: $4',
'file-nohires'   => 'Ingaa pinosodia risoluson takawas.',
'svg-long-desc'  => 'Pail SVG,  tipong tuou $1 × $2 piksol, ginayo pail: $3',
'show-big-image' => 'Sinaisan poimponu',

# Bad image list
'bad_image_list' => 'Kouludan nopo nga miagal dilo siriba:

Iri ahal poinlis (baris di tumimpuun *) maan pitimbango.
Toput kumoiso id baris nokomoi nopo nga toput kumaa id pail naraag.
Awu nokohompit iri nonggo-nonggo toput suai id baris dilo, miagal do kiharo ilo pail.',

# Metadata
'metadata'          => 'Datamata',
'metadata-help'     => 'Pail diti kisuang kointalangan poinruhang, it pinoruhang kaanto mantad gagambar dijital toi minomoguno do pamamadalin do momonsoi toi pinopodijit dilo.
Nung nomodipait no ilo pail, kiharo pipiro kointalangan di awu ogonop do pootulon montok di pail nomodipait.',
'metadata-expand'   => 'Pokitono kointalangan pinatapil',
'metadata-collapse' => 'Polisoko kointalangan pinatapil',
'metadata-fields'   => 'Batas pongodata it poinlis id suang pason diti maan poruhango id upa bolikon pongintalangan nung olisok jodual pongodata.
Iri suai sinandad do poinlisok.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# External editor support
'edit-externally'      => 'Idito pail diti momoguno do kangkaraja pongi-ngidit poinlabus',
'edit-externally-help' => '(Intaai [https://www.mediawiki.org/wiki/Manual:External_editors karalan-ralanon papasang] do lobi gumu kointalangan)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'oinsanan',
'namespacesall' => 'oinsanan',
'monthsall'     => 'oinsanan',

# Watchlist editing tools
'watchlisttools-view' => 'Intaai kinoolonon di kosudong',
'watchlisttools-edit' => 'Intaai om idito lis piintangan',
'watchlisttools-raw'  => 'Idito lis piintangan it mata',

# Core parser functions
'duplicate-defaultsort' => '\'\'\'Panansarahan:\'\'\' Popoguli nuludan kunsi "$2" mongolon nuludan kunsi nokopogulu "$1".',

# Special:SpecialPages
'specialpages' => 'Bolikon suaikowokon',

# External image whitelist
'external_image_whitelist' => ' #Pologoson baris diti<pre>
#Suangai do boros koubasanan (guas boros id pialatan //) ponongsiriba
#Noputan di kaagal pojodion do toput poinsuang (toput koubasanan) do tangagambar
#Toput di kaagal no silihon do gambar, nung awu nga okito o noputan sinuratan
#Baris di kisimbol do # nopo nga ointutunan sobaagi do bolotok
#Tumanud do pisuaian A om a

#Posurato toinsanan id sawat do garis diti. Pologoson iti garis miagal diti</pre>',

# Special:Tags
'tag-filter' => '[[Special:Tags|Pananda]] gagan:',

# New logging system
'revdelete-restricted'   => 'pinokogos pogoduhan montok momuruan',
'revdelete-unrestricted' => 'pinoidu pogoduhan montok momuruan',

);
